@@ -274,24 +274,24 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_tc()
         readNext();
         BREAK_IF_END_OF(CURRENT_EL)
         if (isStartElement()) {
-            if(qualifiedName() == "a:txBody") {
+            if (qualifiedName() == "a:txBody") {
                 QBuffer buffer;
 
                 KoXmlWriter* oldBody = body;
                 KoXmlWriter newBody(&buffer, oldBody->indentLevel()+1);
                 body = &newBody;
 
-                TRY_READ(DrawingML_txBody);
+                TRY_READ_IN_CONTEXT(DrawingML_txBody);
 
                 KoRawCellChild* textChild = new KoRawCellChild(buffer.data());
                 cell->appendChild(textChild);
 
                 body = oldBody;
             }
-//             ELSE_TRY_READ_IF(extLst)
+            // ELSE_TRY_READ_IF(extLst)
             ELSE_TRY_READ_IF(tcPr)
             SKIP_UNKNOWN
-//             ELSE_WRONG_FORMAT
+            // ELSE_WRONG_FORMAT
         }
     }
 
