@@ -154,45 +154,21 @@ Document::~Document()
     delete m_tableHandler;
     delete m_replacementHandler;
     delete m_graphicsHandler;
-    //expecting the background-color of the document on top of the stack
+
+    // expecting the background-color of the document on top of the stack
     Q_ASSERT(m_bgColors.size() == 1);
     m_bgColors.clear();
 }
 
-//set whether or not document has header or footer
-//set tabstop value
-//add footnote settings & endnote settings
-//write out header & footer type
-//write out picture information
 void Document::finishDocument()
 {
     kDebug(30513);
 
-    //finish a header if we need to - this should only be necessary if there's
-    //an even header w/o an odd header
-//     if (m_oddOpen) {
-//         QString contents = QString::fromUtf8(m_buffer->buffer(), m_buffer->buffer().size());
-//         m_masterStyle->addChildElement(QString::number(m_headerCount), contents);
-
-//         m_oddOpen = false;
-//         delete m_headerWriter;
-//         m_headerWriter = 0;
-//         delete m_buffer;
-//         m_buffer = 0;
-//         //we're done with this header, so reset to false
-//         m_writingHeader = false;
-//     }
-
     const wvWare::Word97::DOP& dop = m_parser->dop();
 
-    m_initialFootnoteNumber = dop.nFtn;
-    m_initialEndnoteNumber = dop.nEdn;
-
-    //"tabStopValue", (double)dop.dxaTab / 20.0
-
     Q_ASSERT(m_mainStyles);
-    if (m_mainStyles) {
 
+    if (m_mainStyles) {
         QString footnoteConfig("<text:notes-configuration "
                                "text:note-class=\"footnote\" "
                                "text:default-style-name=\"Footnote\" "
@@ -201,18 +177,19 @@ void Document::finishDocument()
                                "text:master-page-name=\"Footnote\" "
                                "style:num-format=\"%1\" "
                                "text:start-value=\"%2\" "
-                               "text:footnotes-position=\"page\" "
-                               "text:start-numbering-at=\"%3\" "
+                               "text:footnotes-position=\"%3\" "
+                               "text:start-numbering-at=\"%4\" "
                                "/>");
         //FIXME: If document that has an nFib <= 0x00D9, then use DOP.  Else
         //use the infos from SEP (sprmSFpc, sprmSRncFtn, sprmSNFtn, sprmSNfcFtnRef).
         m_mainStyles->insertRawOdfStyles(KoGenStyles::DocumentStyles,
                                          footnoteConfig.arg(Conversion::numberFormatCode(dop.nfcFtnRef2))
-                                                       .arg(m_initialFootnoteNumber)
-                                                       .arg(Conversion::rncToStartNumberingAt(dop.rncFtn))
-                                                       .toLatin1());
+                                         .arg(dop.nFtn)
+                                         .arg(Conversion::fpcToFtnPosition(dop.fpc))
+                                         .arg(Conversion::rncToStartNumberingAt(dop.rncFtn))
+                                         .toLatin1());
 
-        // ms-word has start-numbering-at (rncEdn) for endnotes, but ODF doesn't really support it
+        // MS Word has start-numbering-at (rncEdn) for endnotes, but ODF doesn't really support it
         QString endnoteConfig("<text:notes-configuration "
                               "text:note-class=\"endnote\" "
                               "text:default-style-name=\"Endnote\" "
@@ -223,50 +200,15 @@ void Document::finishDocument()
                               "text:start-value=\"%2\" "
                               //"text:start-numbering-at=\"%3\" "
                               "/>");
+
         //FIXME: If document that has an nFib <= 0x00D9, then use DOP.  Else
         //use the infos from SEP (sprmSFEndnote, sprmSRncEdn, sprmSNEdn, sprmSNfcEdnRef).
         m_mainStyles->insertRawOdfStyles(KoGenStyles::DocumentStyles,
                                          endnoteConfig.arg(Conversion::numberFormatCode(dop.nfcEdnRef2))
-                                                      .arg(m_initialEndnoteNumber)
-//                                                           .arg(Conversion::rncToStartNumberingAt(dop.rncEdn))
-                                                      .toLatin1());
+                                         .arg(dop.nEdn)
+                                         // .arg(Conversion::rncToStartNumberingAt(dop.rncEdn))
+                                         .toLatin1());
     }
-//     QDomElement elementDoc = m_mainDocument.documentElement();
-//     QDomElement element;
-//     element = m_mainDocument.createElement("ATTRIBUTES");
-//     element.setAttribute("processing",0); // WP
-//     char allHeaders = ( wvWare::HeaderData::HeaderEven |
-//                         wvWare::HeaderData::HeaderOdd |
-//                         wvWare::HeaderData::HeaderFirst );
-//     element.setAttribute("hasHeader", m_headerFooters & allHeaders ? 1 : 0 );
-//     char allFooters = ( wvWare::HeaderData::FooterEven |
-//                         wvWare::HeaderData::FooterOdd |
-//                         wvWare::HeaderData::FooterFirst );
-//     element.setAttribute("hasFooter", m_headerFooters & allFooters ? 1 : 0 );
-//     //element.setAttribute("unit","mm"); // How to figure out the unit to use?
-
-//     element.setAttribute("tabStopValue", (double)dop.dxaTab / 20.0 );
-//     elementDoc.appendChild(element);
-
-//     // Done at the end: write the type of headers/footers,
-//     // depending on which kind of headers and footers we received.
-//     QDomElement paperElement = elementDoc.namedItem("PAPER").toElement();
-//     Q_ASSERT ( !paperElement.isNull() ); // slotSectionFound should have been called!
-//     if ( !paperElement.isNull() ) {
-//         kDebug(30513) <<"m_headerFooters=" << m_headerFooters;
-//         paperElement.setAttribute("hType", Conversion::headerMaskToHType( m_headerFooters ) );
-//         paperElement.setAttribute("fType", Conversion::headerMaskToFType( m_headerFooters ) );
-//     }
-
-//     // Write out <PICTURES> tag
-//     QDomElement picturesElem = m_mainDocument.createElement("PICTURES");
-//     elementDoc.appendChild( picturesElem );
-//     for( QStringList::Iterator it = m_pictureList.begin(); it != m_pictureList.end(); ++it ) {
-//         QDomElement keyElem = m_mainDocument.createElement("KEY");
-//         picturesElem.appendChild( keyElem );
-//         keyElem.setAttribute( "filename", *it );
-//         keyElem.setAttribute( "name", *it );
-//     }
 }
 
 //write document info, author, fullname, title, about
@@ -858,103 +800,6 @@ void Document::annotationEnd()
 {
 }
 
-//NOTE: disable this for now - we should be able to do everything in
-//TableHandler create frame for the table cell?
-// void Document::slotTableCellStart( int row, int column, int rowSpan, int columnSpan, const QRectF& cellRect,
-//                                    const QString& tableName,
-//                                    const wvWare::Word97::BRC& brcTop, const wvWare::Word97::BRC& brcBottom,
-//                                    const wvWare::Word97::BRC& brcLeft, const wvWare::Word97::BRC& brcRight,
-//                                    const wvWare::Word97::SHD& shd )
-// {
-//     kDebug(30513) ;
-
-//     //need to set up cell style here probably don't need generateFrameBorder()
-//     //<table:table-cell> tag in content.xml
-
-//     QDomElement framesetElement = m_mainDocument.createElement("FRAMESET");
-//     framesetElement.setAttribute( "frameType", 1 /* text */ );
-//     framesetElement.setAttribute( "frameInfo", 0 /* normal text */ );
-//     framesetElement.setAttribute( "grpMgr", tableName );
-//     QString name = i18nc("Table_Name Cell row,column", "%1 Cell %2,%3",tableName,row,column);
-//     framesetElement.setAttribute( "name", name );
-//     framesetElement.setAttribute( "row", row );
-//     framesetElement.setAttribute( "col", column );
-//     framesetElement.setAttribute( "rows", rowSpan );
-//     framesetElement.setAttribute( "cols", columnSpan );
-//     m_framesetsElement.appendChild(framesetElement);
-
-//     QDomElement frameElem = createInitialFrame( framesetElement, cellRect.left(), cellRect.right(), cellRect.top(), cellRect.bottom(), true, NoFollowup );
-//     generateFrameBorder( frameElem, brcTop, brcBottom, brcLeft, brcRight, shd );
-
-//     m_textHandler->setFrameSetElement( framesetElement );
-// }
-
-//add empty element to end it?
-// void Document::slotTableCellEnd()
-// {
-//     kDebug(30513) ;
-//     //</table:table-cell>
-//     m_textHandler->setFrameSetElement( QDomElement() );
-// }
-
-//set up frame borders (like for a table cell?)
-//set the background fill
-// void Document::generateFrameBorder( QDomElement& frameElementOut,
-//                                     const wvWare::Word97::BRC& brcTop, const wvWare::Word97::BRC& brcBottom,
-//                                     const wvWare::Word97::BRC& brcLeft, const wvWare::Word97::BRC& brcRight,
-//                                     const wvWare::Word97::SHD& shd )
-// {
-//     kDebug(30513) ;
-//     // Frame borders
-//     //figure out what this is supposed to do!
-
-//     if ( brcTop.ico != 255 && brcTop.dptLineWidth != 255 ) // see tablehandler.cpp
-//     Conversion::setBorderAttributes( frameElementOut, brcTop, "t" );
-//     if ( brcBottom.ico != 255 && brcBottom.dptLineWidth != 255 ) // see tablehandler.cpp
-//     Conversion::setBorderAttributes( frameElementOut, brcBottom, "b" );
-//     if ( brcLeft.ico != 255 && brcLeft.dptLineWidth != 255 ) // could still be 255, for first column
-//     Conversion::setBorderAttributes( frameElementOut, brcLeft, "l" );
-//     if ( brcRight.ico != 255 && brcRight.dptLineWidth != 255 ) // could still be 255, for last column
-//     Conversion::setBorderAttributes( frameElementOut, brcRight, "r" );
-
-//     // Frame background brush (color and fill style)
-//     if ( shd.icoFore != 0 || shd.icoBack != 0 )
-//     {
-//         // If ipat = 0 (solid fill), icoBack is the background color.  But
-//         // otherwise, icoFore is the one we need to set as bkColor (and icoBack
-//         // is usually white; it's the other color of the pattern, something
-//         // that we can't set in Qt apparently).
-//     int bkColor = shd.ipat ? shd.icoFore : shd.icoBack;
-//     kDebug(30513) <<"generateFrameBorder:" <<" icoFore=" << shd.icoFore <<" icoBack=" << shd.icoBack <<" ipat=" << shd.ipat <<" -> bkColor=" << bkColor;
-
-//         // Reverse-engineer MSWord's own hackery: it models various gray levels
-//         // using dithering. But this looks crappy with Qt. So we go back to a
-//         // QColor.
-//         bool grayHack = ( shd.ipat && shd.icoFore == 1 && shd.icoBack == 8 );
-//         if ( grayHack )
-//         {
-//             bool ok;
-//             int grayLevel = Conversion::ditheringToGray( shd.ipat, &ok );
-//             if ( ok )
-//             {
-//                 QColor color( 0, 0, grayLevel, QColor::Hsv );
-//                 QString prefix = "bk";
-//                 frameElementOut.setAttribute( "bkRed", color.red() );
-//                 frameElementOut.setAttribute( "bkBlue", color.blue() );
-//                 frameElementOut.setAttribute( "bkGreen", color.green() );
-//             }
-//             else grayHack = false;
-//         }
-//         if ( !grayHack )
-//         {
-//             Conversion::setColorAttributes( frameElementOut, bkColor, "bk", true );
-//             //Fill style
-//             int brushStyle = Conversion::fillPatternStyle( shd.ipat );
-//             frameElementOut.setAttribute( "bkStyle", brushStyle );
-//         }
-//     }
-// }
-
 //create SubDocument object & add it to the queue
 void Document::slotSubDocFound(const wvWare::FunctorBase* functor, int data)
 {
@@ -1037,8 +882,10 @@ void Document::slotTextBoxFound(unsigned int index, bool stylesxml)
 void Document::processSubDocQueue()
 {
     kDebug(30513) ;
+
     // Table cells can contain footnotes, and footnotes can contain tables [without footnotes though]
     // This is why we need to repeat until there's nothing more do to (#79024)
+
     while (!m_subdocQueue.empty()) {// || !m_tableQueue.empty()) {
         while (!m_subdocQueue.empty()) {
             SubDocument subdoc(m_subdocQueue.front());
