@@ -32,10 +32,8 @@ WizardExtension::~WizardExtension()
 {
 }
 
-Part::Part( QWidget *parentWidget,
-            QObject *parent,
-            bool singleViewMode )
-    : KoDocument( parentWidget, parent, singleViewMode )
+Part::Part(QObject *parent)
+    : KoDocument(parent)
 {
 }
 
