@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2007 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2012 Jarosław Staniek <staniek@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -59,6 +59,8 @@
 
 #include <kexi_global.h>
 
+//#define MAX_FIELDS 101 //nice prime number
+
 //! used only for BLOBs
 #define DEFAULT_OBJECT_TYPE_VALUE "image"
 
@@ -265,9 +267,9 @@ void KexiTableDesignerView::initData()
 //  d->sets->clear();//default size
 // }
 
-    //add empty space, at least 2 times more than number of existing fields
-    uint fullSize = qMax(d->sets->size(), uint(2 * tableFieldCount));
-    for (int i = tableFieldCount; i < fullSize; i++) {
+    //add empty space
+// const int columnsCount = d->data->columnsCount();
+    for (int i = tableFieldCount; i < (int)d->sets->size(); i++) {
 //  KexiDB::RecordData *item = new KexiDB::RecordData(columnsCount);//3 empty fields
         d->data->append(d->data->createItem());
     }
@@ -396,7 +398,11 @@ KexiTableDesignerView::createPropertySet(int row, const KexiDB::Field& field, bo
                      = new KoProperty::Property("unsigned", QVariant(field.isUnsigned()), i18n("Unsigned Number")));
 
     set->addProperty(prop
-                     = new KoProperty::Property("maxLength", (int)field.maxLength()/*200?*/, i18n("Length")));
+                     = new KoProperty::Property("maxLength", (uint)field.maxLength(), i18n("Max Length")));
+
+    set->addProperty(prop
+                     = new KoProperty::Property("maxLengthIsDefault", field.maxLengthStrategy() == KexiDB::Field::DefaultMaxLength));
+    prop->setVisible(false);//always hidden
 
     set->addProperty(prop
                      = new KoProperty::Property("precision", (int)field.precision()/*200?*/, i18n("Precision")));
@@ -880,12 +886,16 @@ void KexiTableDesignerView::slotRowUpdated(KexiDB::RecordData *record)
         QString fieldName(KexiUtils::string2Identifier(fieldCaption));
 
         KexiDB::Field::Type fieldType = KexiDB::intToFieldType(intFieldType);
+        uint maxLength = 0;
+        if (fieldType == KexiDB::Field::Text) {
+            maxLength = KexiDB::Field::defaultMaxLength();
+        }
         KexiDB::Field field( //tmp
             fieldName,
             fieldType,
             KexiDB::Field::NoConstraints,
             KexiDB::Field::NoOptions,
-            /*length*/0,
+            maxLength,
             /*precision*/0,
             /*defaultValue*/QVariant(),
             fieldCaption,
@@ -894,9 +904,15 @@ void KexiTableDesignerView::slotRowUpdated(KexiDB::RecordData *record)
 //  m_newTable->addField( field );
 
         // reasonable case for boolean type: set notNull flag and "false" as default value
-        if (fieldType == KexiDB::Field::Boolean) {
+        switch (fieldType) {
+        case KexiDB::Field::Boolean:
             field.setNotNull(true);
             field.setDefaultValue(QVariant(false));
+            break;
+        case KexiDB::Field::Text:
+            field.setMaxLengthStrategy(KexiDB::Field::DefaultMaxLength);
+            break;
+        default:;
         }
 
         kDebug() << field.debugString();
