@@ -23,9 +23,9 @@
 #include "KexiProjectListViewItem.h"
 
 #include <q3header.h>
-#include <qpoint.h>
-#include <qpixmapcache.h>
-#include <qtoolbutton.h>
+#include <QPoint>
+#include <QPixmapCache>
+#include <QToolButton>
 #include <QKeyEvent>
 #include <QEvent>
 
@@ -193,7 +193,7 @@ KexiProjectListView::KexiProjectListView(QWidget* parent, Features features)
         }
     }
 
-    m_executeAction = addAction("data_execute", KIcon("media-playback-start"), i18n("Execute"),
+    m_executeAction = addAction("data_execute", KIcon("system-run"), i18n("Execute"),
 //! @todo tooltip, what's this
                                 QString(), QString(),
                                 SLOT(slotExecuteObject()));
