@@ -59,7 +59,7 @@
 #include <KAction>
 
 #ifndef KEXI_NO_PRINT
-#include <QtGui/QPrinter>
+#include <QPrinter>
 #endif
 
 #include "kexitableview.h"
@@ -82,8 +82,8 @@ KexiTableView::Appearance::Appearance(QWidget *widget)
     //set defaults
     if (qApp) {
         baseColor = KColorScheme(QPalette::Active, KColorScheme::View).background().color()/*QPalette::Base*/;
-        textColor = QPalette::Text;
-        borderColor = QColor(200, 200, 200);
+        textColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color()/*QPalette::Base*/;
+        borderColor = KColorScheme(QPalette::Active, KColorScheme::View).shade(KColorScheme::LightShade);
         emptyAreaColor = KColorScheme(QPalette::Active, KColorScheme::View).background().color()/*QPalette::Base*/;
         recordHighlightingColor = KexiUtils::blendedColors(QPalette::Highlight, baseColor, 33, 66);
         recordMouseOverHighlightingColor = KexiUtils::blendedColors(QPalette::Highlight, baseColor, 10, 90);
@@ -2678,6 +2678,11 @@ void KexiTableView::slotContentsMoving(int x, int y)
     updateContents(); // (js) needed in Qt 4, no idea why, this fix consumed me hours
 }*/
 
+int KexiTableView::horizontalHeaderHeight() const
+{
+    return m_horizontalHeader->height();
+}
+
 QWidget* KexiTableView::navPanelWidget() const
 {
     return dynamic_cast<QWidget*>(m_navPanel);
