@@ -49,7 +49,6 @@
 #include "kis_filter_strategy.h"
 #include "kis_group_layer.h"
 #include "commands/kis_image_commands.h"
-#include "kis_iterators_pixel.h"
 #include "kis_layer.h"
 #include "kis_meta_data_merge_strategy_registry.h"
 #include "kis_name_server.h"
@@ -58,7 +57,6 @@
 #include "kis_painter.h"
 #include "kis_perspective_grid.h"
 #include "kis_selection.h"
-#include "kis_shear_visitor.h"
 #include "kis_transaction.h"
 #include "kis_transform_visitor.h"
 #include "kis_types.h"
@@ -78,15 +76,16 @@
 #include "commands_new/kis_image_resize_command.h"
 #include "commands_new/kis_image_set_resolution_command.h"
 #include "kis_composite_progress_proxy.h"
+#include "kis_layer_composition.h"
 
 
 // #define SANITY_CHECKS
 
 #ifdef SANITY_CHECKS
 #define SANITY_CHECK_LOCKED(name)                                       \
-    if(!locked()) qDebug() << "Locking policy failed:" << name          \
-                           << "has been called without the image"       \
-                              "being locked";
+    if (!locked()) warnKrita() << "Locking policy failed:" << name          \
+                               << "has been called without the image"       \
+                                  "being locked";
 #else
 #define SANITY_CHECK_LOCKED(name)
 #endif
@@ -110,8 +109,10 @@ public:
 
     const KoColorSpace * colorSpace;
 
+    KisSelectionSP deselectedGlobalSelection;
     KisGroupLayerSP rootLayer; // The layers are contained in here
     QList<KisLayer*> dirtyLayers; // for thumbnails
+    QList<KisLayerComposition*> compositions;
 
     KisNameServer *nserver;
 
@@ -123,9 +124,6 @@ public:
 
     vKisAnnotationSP annotations;
 
-    KisSelectionSP globalSelection;
-    KisSelectionSP deselectedGlobalSelection;
-
     QAtomicInt disableUIUpdateSignals;
     KisImageSignalRouter *signalRouter;
     KisUpdateScheduler *scheduler;
@@ -174,71 +172,81 @@ KisImage::~KisImage()
     disconnect(); // in case Qt gets confused
 }
 
-void KisImage::aboutToAddANode(KisNode *parent, int index)
-{
-    SANITY_CHECK_LOCKED("aboutToAddANode");
-    m_d->signalRouter->emitAboutToAddANode(parent, index);
-}
-
 void KisImage::nodeHasBeenAdded(KisNode *parent, int index)
 {
+    KisNodeGraphListener::nodeHasBeenAdded(parent, index);
+
+    SANITY_CHECK_LOCKED("nodeHasBeenAdded");
     m_d->signalRouter->emitNodeHasBeenAdded(parent, index);
 }
 
 void KisImage::aboutToRemoveANode(KisNode *parent, int index)
 {
+    KisNodeGraphListener::aboutToRemoveANode(parent, index);
+
     SANITY_CHECK_LOCKED("aboutToRemoveANode");
     m_d->signalRouter->emitAboutToRemoveANode(parent, index);
 }
 
-void KisImage::nodeHasBeenRemoved(KisNode *parent, int index)
-{
-    // XXX: Temporarily for compatibility
-    m_d->signalRouter->emitNodeHasBeenRemoved(parent, index);
-}
-
-void KisImage::aboutToMoveNode(KisNode *parent, int oldIndex, int newIndex)
-{
-    SANITY_CHECK_LOCKED("aboutToMoveNode");
-    m_d->signalRouter->emitAboutToMoveNode(parent, oldIndex, newIndex);
-}
-
-void KisImage::nodeHasBeenMoved(KisNode *parent, int oldIndex, int newIndex)
-{
-    m_d->signalRouter->emitNodeHasBeenMoved(parent, oldIndex, newIndex);
-}
-
 void KisImage::nodeChanged(KisNode* node)
 {
+    KisNodeGraphListener::nodeChanged(node);
+
     m_d->signalRouter->emitNodeChanged(node);
 }
 
 KisSelectionSP KisImage::globalSelection() const
 {
-    return m_d->globalSelection;
+    KisSelectionMaskSP selectionMask = m_d->rootLayer->selectionMask();
+    if (selectionMask) {
+        return selectionMask->selection();
+    } else {
+        return 0;
+    }
 }
 
 void KisImage::setGlobalSelection(KisSelectionSP globalSelection)
 {
-    if (globalSelection == 0)
-        m_d->globalSelection = new KisSelection(new KisDefaultBounds(this));
-    else
-        m_d->globalSelection = globalSelection;
+    KisSelectionMaskSP selectionMask = m_d->rootLayer->selectionMask();
+
+    if (!globalSelection) {
+        if (selectionMask) {
+            removeNode(selectionMask);
+        }
+    }
+    else {
+        if (!selectionMask) {
+            selectionMask = new KisSelectionMask(this);
+            addNode(selectionMask);
+            selectionMask->setActive(true);
+        }
+        selectionMask->setSelection(globalSelection);
+
+        Q_ASSERT(m_d->rootLayer->childCount() > 0);
+        Q_ASSERT(m_d->rootLayer->selectionMask());
+    }
+
+    m_d->deselectedGlobalSelection = 0;
+    m_d->legacyUndoAdapter->emitSelectionChanged();
 }
 
-void KisImage::removeGlobalSelection()
+void KisImage::deselectGlobalSelection()
 {
-    m_d->globalSelection = 0;
+    KisSelectionSP savedSelection = globalSelection();
+    setGlobalSelection(0);
+    m_d->deselectedGlobalSelection = savedSelection;
 }
 
-KisSelectionSP KisImage::deselectedGlobalSelection()
+bool KisImage::canReselectGlobalSelection()
 {
     return m_d->deselectedGlobalSelection;
 }
 
-void KisImage::setDeleselectedGlobalSelection(KisSelectionSP selection)
+void KisImage::reselectGlobalSelection()
 {
-    m_d->deselectedGlobalSelection = selection;
+    if(m_d->deselectedGlobalSelection) {
+        setGlobalSelection(m_d->deselectedGlobalSelection);
+    }
 }
 
 KisBackgroundSP KisImage::backgroundPattern() const
@@ -281,7 +289,7 @@ void KisImage::init(KisUndoStore *undoStore, qint32 width, qint32 height, const
 
     m_d->signalRouter = new KisImageSignalRouter(this);
 
-    if(!undoStore) {
+    if (!undoStore) {
         undoStore = new KisDumbUndoStore();
     }
 
@@ -342,12 +350,12 @@ bool KisImage::tryBarrierLock()
             result = m_d->scheduler->tryBarrierLock();
         }
 
-        if(result) {
+        if (result) {
             m_d->sizeChangedWhileLocked = false;
         }
     }
 
-    if(result) {
+    if (result) {
         m_d->lockCount++;
     }
 
@@ -415,7 +423,7 @@ void KisImage::setSize(const QSize& size)
 
 void KisImage::resizeImageImpl(const QRect& newRect, bool cropLayers)
 {
-    if(newRect == bounds()) return;
+    if (newRect == bounds() && !cropLayers) return;
 
     QString actionName = cropLayers ? i18n("Crop Image") : i18n("Resize Image");
 
@@ -427,7 +435,7 @@ void KisImage::resizeImageImpl(const QRect& newRect, bool cropLayers)
                                        KisProcessingApplicator::NO_UI_UPDATES,
                                        emitSignals, actionName);
 
-    if(cropLayers || !newRect.topLeft().isNull()) {
+    if (cropLayers || !newRect.topLeft().isNull()) {
         KisProcessingVisitorSP visitor =
             new KisCropProcessingVisitor(newRect, cropLayers, true);
         applicator.applyVisitor(visitor, KisStrokeJobData::CONCURRENT);
@@ -455,7 +463,7 @@ void KisImage::cropNode(KisNodeSP node, const QRect& newRect)
     emitSignals << ModifiedSignal;
 
     KisProcessingApplicator applicator(this, node,
-                                       KisProcessingApplicator::NONE,
+                                       KisProcessingApplicator::RECURSIVE,
                                        emitSignals, actionName);
 
     KisProcessingVisitorSP visitor =
@@ -478,7 +486,7 @@ void KisImage::scaleImage(const QSize &size, qreal xres, qreal yres, KisFilterSt
     bool resolutionChanged = xres != xRes() && yres != yRes();
     bool sizeChanged = size != this->size();
 
-    if(!resolutionChanged && !sizeChanged) return;
+    if (!resolutionChanged && !sizeChanged) return;
 
     KisImageSignalVector emitSignals;
     if (resolutionChanged) emitSignals << ResolutionChangedSignal;
@@ -502,7 +510,7 @@ void KisImage::scaleImage(const QSize &size, qreal xres, qreal yres, KisFilterSt
 
     QTransform shapesCorrection;
 
-    if(resolutionChanged) {
+    if (resolutionChanged) {
         shapesCorrection = QTransform::fromScale(xRes() / xres, yRes() / yres);
     }
 
@@ -531,34 +539,53 @@ void KisImage::scaleImage(const QSize &size, qreal xres, qreal yres, KisFilterSt
     applicator.end();
 }
 
-void KisImage::rotate(double radians)
+void KisImage::rotateImpl(const QString &actionName,
+                          KisNodeSP rootNode,
+                          bool resizeImage,
+                          double radians)
 {
-    qint32 w = width();
-    qint32 h = height();
-    qint32 tx = qint32((w * cos(radians) - h * sin(radians) - w) / 2 + 0.5);
-    qint32 ty = qint32((h * cos(radians) + w * sin(radians) - h) / 2 + 0.5);
-    w = (qint32)(width() * qAbs(cos(radians)) + height() * qAbs(sin(radians)) + 0.5);
-    h = (qint32)(height() * qAbs(cos(radians)) + width() * qAbs(sin(radians)) + 0.5);
+    QPointF offset;
+    QSize newSize;
 
-    tx -= (w - width()) / 2;
-    ty -= (h - height()) / 2;
+    {
+        KisTransformWorker worker(0,
+                                  1.0, 1.0,
+                                  0, 0, 0, 0,
+                                  radians,
+                                  0, 0, 0, 0);
+        QTransform transform = worker.transform();
+
+        if (resizeImage) {
+            QRect newRect = transform.mapRect(bounds());
+            newSize = newRect.size();
+            offset = -newRect.topLeft();
+        }
+        else {
+            QPointF origin = QRectF(rootNode->exactBounds()).center();
+
+            newSize = size();
+            offset = -(transform.map(origin) - origin);
+        }
+    }
+
+    bool sizeChanged = resizeImage &&
+        (newSize.width() != width() || newSize.height() != height());
 
     // These signals will be emitted after processing is done
     KisImageSignalVector emitSignals;
-    if (w != width() || h != height()) emitSignals << SizeChangedSignal;
+    if (sizeChanged) emitSignals << SizeChangedSignal;
     emitSignals << ModifiedSignal;
 
     // These flags determine whether updates are transferred to the UI during processing
     KisProcessingApplicator::ProcessingFlags signalFlags =
-        (emitSignals.contains(SizeChangedSignal)) ?
-                KisProcessingApplicator::NO_UI_UPDATES :
-                KisProcessingApplicator::NONE;
+        sizeChanged ?
+        KisProcessingApplicator::NO_UI_UPDATES :
+        KisProcessingApplicator::NONE;
 
 
-    // XXX i18n("Rotate Image") after 2.4
-    KisProcessingApplicator applicator(this, m_d->rootLayer,
+    KisProcessingApplicator applicator(this, rootNode,
                                        KisProcessingApplicator::RECURSIVE | signalFlags,
-                                       emitSignals, "Rotate Image");
+                                       emitSignals, actionName);
 
     KisFilterStrategy *filter = KisFilterStrategyRegistry::instance()->value("Triangle");
 
@@ -566,55 +593,101 @@ void KisImage::rotate(double radians)
             new KisTransformProcessingVisitor(1.0, 1.0, 0.0, 0.0,
                                               QPointF(),
                                               radians,
-                                              -tx, -ty, filter);
+                                              offset.x(), offset.y(),
+                                              filter);
 
     applicator.applyVisitor(visitor, KisStrokeJobData::CONCURRENT);
 
-    if (w != width() || h != height()) {
-        applicator.applyCommand(new KisImageResizeCommand(this, QSize(w,h)));
+    if (sizeChanged) {
+        applicator.applyCommand(new KisImageResizeCommand(this, newSize));
     }
     applicator.end();
 }
 
-void KisImage::shear(double angleX, double angleY, KoUpdater *progress)
+
+void KisImage::rotateImage(double radians)
 {
-    const double pi = 3.1415926535897932385;
+    // XXX i18n("Rotate Image") after 2.4
+    rotateImpl("Rotate Image", root(), true, radians);
+}
 
-    //new image size
-    qint32 w = width();
-    qint32 h = height();
+void KisImage::rotateNode(KisNodeSP node, double radians)
+{
+    rotateImpl(i18n("Rotate Layer"), node, false, radians);
+}
 
+void KisImage::shearImpl(const QString &actionName,
+                         KisNodeSP rootNode,
+                         bool resizeImage,
+                         double angleX, double angleY,
+                         const QPointF &origin)
+{
+    //angleX, angleY are in degrees
+    const qreal pi = 3.1415926535897932385;
+    const qreal deg2rad = pi / 180.0;
 
-    if (angleX != 0 || angleY != 0) {
-        double deltaY = height() * qAbs(tan(angleX * pi / 180) * tan(angleY * pi / 180));
-        w = (qint32)(width() + qAbs(height() * tan(angleX * pi / 180)));
-        //ugly fix for the problem of having two extra pixels if only a shear along one
-        //axis is done.
-        if (angleX == 0 || angleY == 0)
-            h = (qint32)(height() + qAbs(w * tan(angleY * pi / 180)));
-        else if (angleX > 0 && angleY > 0)
-            h = (qint32)(height() + qAbs(w * tan(angleY * pi / 180)) - 2 * deltaY + 2);
-        else if (angleX < 0 && angleY < 0)
-            h = (qint32)(height() + qAbs(w * tan(angleY * pi / 180)) - 2 * deltaY + 2);
-        else
-            h = (qint32)(height() + qAbs(w * tan(angleY * pi / 180)));
+    qreal tanX = tan(angleX * deg2rad);
+    qreal tanY = tan(angleY * deg2rad);
+
+    QPointF offset;
+    QSize newSize;
+
+    {
+        KisTransformWorker worker(0,
+                                  1.0, 1.0,
+                                  tanX, tanY, origin.x(), origin.y(),
+                                  0,
+                                  0, 0, 0, 0);
+
+        QRect newRect = worker.transform().mapRect(bounds());
+        newSize = newRect.size();
+        if (resizeImage) offset = -newRect.topLeft();
     }
 
-    QSize newSize(w, h);
-    if(newSize == size()) return;
+    if (newSize == size()) return;
 
-    undoAdapter()->beginMacro(i18n("Shear Image"));
-    undoAdapter()->addCommand(new KisImageLockCommand(KisImageWSP(this), true));
-    undoAdapter()->addCommand(new KisImageResizeCommand(KisImageWSP(this), newSize));
+    KisImageSignalVector emitSignals;
+    if (resizeImage) emitSignals << SizeChangedSignal;
+    emitSignals << ModifiedSignal;
 
-    KisShearVisitor visitor(angleX, angleY, progress);
-    visitor.setUndoAdapter(undoAdapter());
-    rootLayer()->accept(visitor);
+    KisProcessingApplicator::ProcessingFlags signalFlags =
+        KisProcessingApplicator::RECURSIVE;
+    if (resizeImage) signalFlags |= KisProcessingApplicator::NO_UI_UPDATES;
 
-    undoAdapter()->addCommand(new KisImageLockCommand(KisImageWSP(this), false));
-    undoAdapter()->endMacro();
+    KisProcessingApplicator applicator(this, rootNode,
+                                       signalFlags,
+                                       emitSignals, actionName);
 
-    setModified();
+    KisFilterStrategy *filter = KisFilterStrategyRegistry::instance()->value("Triangle");
+
+    KisProcessingVisitorSP visitor =
+            new KisTransformProcessingVisitor(1.0, 1.0,
+                                              tanX, tanY, origin,
+                                              0,
+                                              offset.x(), offset.y(),
+                                              filter);
+
+    applicator.applyVisitor(visitor, KisStrokeJobData::CONCURRENT);
+
+    if (resizeImage) {
+        applicator.applyCommand(new KisImageResizeCommand(this, newSize));
+    }
+
+    applicator.end();
+}
+
+void KisImage::shearNode(KisNodeSP node, double angleX, double angleY)
+{
+    QPointF shearOrigin = QRectF(bounds()).center();
+
+    shearImpl(i18n("Shear layer"), node, false,
+              angleX, angleY, shearOrigin);
+}
+
+void KisImage::shear(double angleX, double angleY)
+{
+    shearImpl(i18n("Shear Image"), m_d->rootLayer, true,
+              angleX, angleY, QPointF());
 }
 
 void KisImage::convertImageColorSpace(const KoColorSpace *dstColorSpace, KoColorConversionTransformation::Intent renderingIntent)
@@ -638,23 +711,19 @@ void KisImage::convertImageColorSpace(const KoColorSpace *dstColorSpace, KoColor
 
 void KisImage::assignImageProfile(const KoColorProfile *profile)
 {
-    if(!profile) return;
-
-    undoAdapter()->beginMacro(i18n("Assign Profile"));
-    undoAdapter()->addCommand(new KisImageLockCommand(KisImageWSP(this), true));
+    if (!profile) return;
 
     const KoColorSpace *dstCs = KoColorSpaceRegistry::instance()->colorSpace(colorSpace()->colorModelId().id(), colorSpace()->colorDepthId().id(), profile);
     const KoColorSpace *srcCs = colorSpace();
 
+    Q_ASSERT(dstCs);
+    Q_ASSERT(srcCs);
+
+    m_d->colorSpace = dstCs;
+
     KisChangeProfileVisitor visitor(srcCs, dstCs);
     m_d->rootLayer->accept(visitor);
 
-    undoAdapter()->addCommand(new KisImageSetProjectionColorSpaceCommand(KisImageWSP(this), dstCs));
-    undoAdapter()->addCommand(new KisImageLockCommand(KisImageWSP(this), false));
-    undoAdapter()->endMacro();
-
-    setModified();
-    m_d->signalRouter->emitNotification(ProfileChangedSignal);
 }
 
 void KisImage::convertProjectionColorSpace(const KoColorSpace *dstColorSpace)
@@ -805,7 +874,7 @@ QRect KisImage::realNodeExtent(KisNodeSP rootNode, QRect currentRect)
 void KisImage::refreshHiddenArea(KisNodeSP rootNode, const QRect &preparedArea)
 {
     QRect realNodeRect = realNodeExtent(rootNode);
-    if(!preparedArea.contains(realNodeRect)) {
+    if (!preparedArea.contains(realNodeRect)) {
 
         QRegion dirtyRegion = realNodeRect;
         dirtyRegion -= preparedArea;
@@ -845,34 +914,54 @@ void KisImage::flatten()
 
 KisLayerSP KisImage::mergeDown(KisLayerSP layer, const KisMetaData::MergeStrategy* strategy)
 {
-    if(!layer->prevSibling()) return 0;
+    if (!layer->prevSibling()) return 0;
 
     // XXX: this breaks if we allow free mixing of masks and layers
     KisLayerSP prevLayer = dynamic_cast<KisLayer*>(layer->prevSibling().data());
     if (!prevLayer) return 0;
 
-
     refreshHiddenArea(layer, bounds());
     refreshHiddenArea(prevLayer, bounds());
 
     QRect layerProjectionExtent = layer->projection()->extent();
     QRect prevLayerProjectionExtent = prevLayer->projection()->extent();
 
-    lock();
-    KisPaintDeviceSP mergedDevice = new KisPaintDevice(*prevLayer->projection());
-    unlock();
+    KisPaintDeviceSP mergedDevice;
 
-    KisPainter gc(mergedDevice);
-    gc.setChannelFlags(layer->channelFlags());
-    gc.setCompositeOp(mergedDevice->colorSpace()->compositeOp(layer->compositeOpId()));
-    gc.setOpacity(layer->opacity());
-    gc.bitBlt(layerProjectionExtent.topLeft(), layer->projection(), layerProjectionExtent);
+    if (layer->compositeOpId() != prevLayer->compositeOpId() || layer->opacity() != prevLayer->opacity()) {
+
+        mergedDevice = new KisPaintDevice(layer->colorSpace(), "merged");
+        KisPainter gc(mergedDevice);
+
+        gc.setChannelFlags(prevLayer->channelFlags());
+        gc.setCompositeOp(mergedDevice->colorSpace()->compositeOp(prevLayer->compositeOpId()));
+        gc.setOpacity(prevLayer->opacity());
+
+        gc.bitBlt(prevLayerProjectionExtent.topLeft(), prevLayer->projection(), prevLayerProjectionExtent);
+
+
+        gc.setChannelFlags(layer->channelFlags());
+        gc.setCompositeOp(mergedDevice->colorSpace()->compositeOp(layer->compositeOpId()));
+        gc.setOpacity(layer->opacity());
+
+        gc.bitBlt(layerProjectionExtent.topLeft(), layer->projection(), layerProjectionExtent);
+    }
+    else {
+        lock();
+        mergedDevice = new KisPaintDevice(*prevLayer->projection());
+        unlock();
+
+        KisPainter gc(mergedDevice);
+        gc.setChannelFlags(layer->channelFlags());
+        gc.setCompositeOp(mergedDevice->colorSpace()->compositeOp(layer->compositeOpId()));
+        gc.setOpacity(layer->opacity());
+        gc.bitBlt(layerProjectionExtent.topLeft(), layer->projection(), layerProjectionExtent);
+    }
 
     KisPaintLayerSP mergedLayer = new KisPaintLayer(this, prevLayer->name(), OPACITY_OPAQUE_U8, mergedDevice);
     Q_CHECK_PTR(mergedLayer);
-    mergedLayer->setCompositeOp(prevLayer->compositeOp()->id());
-    mergedLayer->setOpacity(prevLayer->opacity());
-    mergedLayer->setChannelFlags(prevLayer->channelFlags());
+    mergedLayer->setCompositeOp(COMPOSITE_OVER);
+    mergedLayer->setChannelFlags(layer->channelFlags());
 
     // Merge meta data
     QList<const KisMetaData::Store*> srcs;
@@ -920,15 +1009,8 @@ KisLayerSP KisImage::flattenLayer(KisLayerSP layer)
 
     undoAdapter()->beginMacro(i18n("Flatten Layer"));
     undoAdapter()->addCommand(new KisImageLayerAddCommand(this, newLayer, layer->parent(), layer));
-
-    KisNodeSP node = layer->firstChild();
-    while (node) {
-        undoAdapter()->addCommand(new KisImageLayerRemoveCommand(this, node));
-        node = node->nextSibling();
-    }
     undoAdapter()->addCommand(new KisImageLayerRemoveCommand(this, layer));
 
-
     QList<const KisMetaData::Store*> srcs;
     srcs.append(layer->metaData());
 
@@ -1136,8 +1218,10 @@ KisActionRecorder* KisImage::actionRecorder() const
 
 void KisImage::setRootLayer(KisGroupLayerSP rootLayer)
 {
-    if(m_d->rootLayer)
+    if (m_d->rootLayer) {
+        m_d->rootLayer->setGraphListener(0);
         m_d->rootLayer->disconnect();
+    }
 
     m_d->rootLayer = rootLayer;
     m_d->rootLayer->disconnect();
@@ -1329,17 +1413,35 @@ void KisImage::enableUIUpdates()
 
 void KisImage::notifyProjectionUpdated(const QRect &rc)
 {
-    if(!m_d->disableUIUpdateSignals) {
+    if (!m_d->disableUIUpdateSignals) {
         emit sigImageUpdated(rc);
     }
 }
 
 void KisImage::requestProjectionUpdate(KisNode *node, const QRect& rect)
 {
+    KisNodeGraphListener::requestProjectionUpdate(node, rect);
+
     if (m_d->scheduler) {
         m_d->scheduler->updateProjection(node, rect, bounds());
     }
 }
 
+QList<KisLayerComposition*> KisImage::compositions()
+{
+    return m_d->compositions;
+}
+
+void KisImage::addComposition(KisLayerComposition* composition)
+{
+    m_d->compositions.append(composition);
+}
+
+void KisImage::removeComposition(KisLayerComposition* composition)
+{
+    m_d->compositions.removeAll(composition);
+    delete composition;
+}
+
 #include "kis_image.moc"
 
