@@ -36,16 +36,12 @@
 
 #include "kis_global.h"
 #include "kis_types.h"
-#include "kis_iterator.h"
-#include "kis_iterators_pixel.h"
-#include "kis_iterator_pixel_trait.h"
-#include "kis_random_accessor.h"
 #include "kis_random_sub_accessor.h"
 #include "kis_selection.h"
 #include "kis_node.h"
 #include "commands/kis_paintdevice_convert_type_command.h"
 #include "kis_datamanager.h"
-#include "kis_default_bounds.h"
+
 #include "kis_selection_component.h"
 #include "kis_pixel_selection.h"
 #include "kis_repeat_iterators_pixel.h"
@@ -56,6 +52,7 @@
 #include "tiles3/kis_rect_iterator.h"
 #include "tiles3/kis_random_accessor.h"
 
+#include "kis_default_bounds.h"
 
 class CacheData : public KisDataManager::AbstractCache
 {
@@ -131,7 +128,7 @@ public:
             cacheThumbnail(w, h, thumbnail);
         }
 
-        Q_ASSERT(!thumbnail.isNull());
+        Q_ASSERT(!thumbnail.isNull() || m_paintDevice->extent().isEmpty());
         return thumbnail;
     }
 
@@ -160,15 +157,14 @@ struct KisPaintDevice::Private
 public:
 
     Private(KisPaintDevice *paintDevice)
-        : defaultBounds(new KisDefaultBounds)
-        , cache(paintDevice)
-        , x(0)
-        , y(0)
+        : cache(paintDevice),
+          x(0),
+          y(0)
     {
     }
 
     KisNodeWSP parent;
-    KisDefaultBounds * defaultBounds;
+    KisDefaultBoundsBaseSP defaultBounds;
     PaintDeviceCache cache;
     qint32 x;
     qint32 y;
@@ -183,7 +179,7 @@ KisPaintDevice::KisPaintDevice(const KoColorSpace * colorSpace, const QString& n
     init(0, colorSpace, new KisDefaultBounds(), 0, name);
 }
 
-KisPaintDevice::KisPaintDevice(KisNodeWSP parent, const KoColorSpace * colorSpace, KisDefaultBounds * defaultBounds, const QString& name)
+KisPaintDevice::KisPaintDevice(KisNodeWSP parent, const KoColorSpace * colorSpace, KisDefaultBoundsBaseSP defaultBounds, const QString& name)
     : QObject(0)
     , m_d(new Private(this))
 {
@@ -203,12 +199,16 @@ KisPaintDevice::KisPaintDevice(KisDataManagerSP explicitDataManager,
 
 void KisPaintDevice::init(KisDataManagerSP explicitDataManager,
                           const KoColorSpace *colorSpace,
-                          KisDefaultBounds * defaultBounds,
+                          KisDefaultBoundsBaseSP defaultBounds,
                           KisNodeWSP parent, const QString& name)
 {
     Q_ASSERT(colorSpace);
     setObjectName(name);
 
+    if (!defaultBounds) {
+        defaultBounds = new KisDefaultBounds();
+    }
+
     m_d->colorSpace = KoColorSpaceRegistry::instance()->grabColorSpace(colorSpace);
     Q_ASSERT(m_d->colorSpace);
 
@@ -330,20 +330,19 @@ void KisPaintDevice::setParentNode(KisNodeWSP parent)
     m_d->parent = parent;
 }
 
-void KisPaintDevice::setDefaultBounds(KisDefaultBounds * defaultBounds)
+// for testing purposes only
+KisNodeWSP KisPaintDevice::parentNode() const
+{
+    return m_d->parent;
+}
+
+void KisPaintDevice::setDefaultBounds(KisDefaultBoundsBaseSP defaultBounds)
 {
-    if (!defaultBounds) {
-        defaultBounds = new KisDefaultBounds();
-    }
-    if (!defaultBounds->parent()) {
-        defaultBounds->moveToThread(QThread::currentThread());
-        defaultBounds->setParent(this);
-    }
     m_d->defaultBounds = defaultBounds;
     m_d->cache.invalidate();
 }
 
-KisDefaultBounds * KisPaintDevice::defaultBounds() const
+KisDefaultBoundsBaseSP KisPaintDevice::defaultBounds() const
 {
     return m_d->defaultBounds;
 }
@@ -397,15 +396,6 @@ QRegion KisPaintDevice::region() const
     return m_d->cache.region();
 }
 
-void KisPaintDevice::exactBounds(qint32 &x, qint32 &y, qint32 &w, qint32 &h) const
-{
-    QRect rc = exactBounds();
-    x = rc.x();
-    y = rc.y();
-    w = rc.width();
-    h = rc.height();
-}
-
 QRect KisPaintDevice::exactBounds() const
 {
     return m_d->cache.exactBounds();
@@ -602,17 +592,18 @@ KUndo2Command* KisPaintDevice::convertTo(const KoColorSpace * dstColorSpace, KoC
             qint32 columns = qMin(numContiguousDstColumns, numContiguousSrcColumns);
             columns = qMin(columns, columnsRemaining);
 
-            KisHLineConstIteratorPixel srcIt = createHLineConstIterator(column, row, columns);
-            KisHLineIteratorPixel dstIt = dst.createHLineIterator(column, row, columns);
+            KisHLineConstIteratorSP srcIt = createHLineConstIteratorNG(column, row, columns);
+            KisHLineIteratorSP dstIt = dst.createHLineIteratorNG(column, row, columns);
 
-            const quint8 *srcData = srcIt.rawData();
-            quint8 *dstData = dstIt.rawData();
+            const quint8 *srcData = srcIt->oldRawData();
+            quint8 *dstData = dstIt->rawData();
 
             m_d->colorSpace->convertPixelsTo(srcData, dstData, dstColorSpace, columns, renderingIntent);
 
             column += columns;
             columnsRemaining -= columns;
         }
+
     }
 
     KisDataManagerSP oldData = m_datamanager;
@@ -755,19 +746,18 @@ KisPaintDeviceSP KisPaintDevice::createThumbnailDevice(qint32 w, qint32 h, const
 
     const qint32 pixelSize = this->pixelSize();
 
-    KisRandomConstAccessorPixel iter = createRandomConstAccessor(0, 0, selection);
-    KisRandomAccessorPixel dstIter = thumbnail->createRandomAccessor(0, 0);
+    KisRandomConstAccessorSP iter = createRandomConstAccessorNG(0, 0);
+    KisRandomAccessorSP dstIter = thumbnail->createRandomAccessorNG(0, 0);
 
     for (qint32 y = 0; y < h; ++y) {
         qint32 iY = srcY0 + (y * srcHeight) / h;
         for (qint32 x = 0; x < w; ++x) {
             qint32 iX = srcX0 + (x * srcWidth) / w;
-            iter.moveTo(iX, iY);
-            dstIter.moveTo(x,  y);
-            memcpy(dstIter.rawData(), iter.rawData(), pixelSize);
+            iter->moveTo(iX, iY);
+            dstIter->moveTo(x,  y);
+            memcpy(dstIter->rawData(), iter->oldRawData(), pixelSize);
         }
     }
-
     return thumbnail;
 
 }
@@ -784,41 +774,6 @@ QImage KisPaintDevice::createThumbnail(qint32 w, qint32 h)
     return m_d->cache.createThumbnail(w, h);
 }
 
-KisRectIteratorPixel KisPaintDevice::createRectIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection)
-{
-    m_d->cache.invalidate();
-
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = selection->projection()->dataManager().data();
-
-    return KisRectIteratorPixel(m_datamanager.data(), selectionDm, left, top, w, h, m_d->x, m_d->y);
-}
-
-KisRectConstIteratorPixel KisPaintDevice::createRectConstIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection) const
-{
-    KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = const_cast< KisDataManager*>(selection->projection()->dataManager().data());
-
-    return KisRectConstIteratorPixel(dm, selectionDm, left, top, w, h, m_d->x, m_d->y);
-}
-
-KisHLineIteratorPixel  KisPaintDevice::createHLineIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection)
-{
-    m_d->cache.invalidate();
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = selection->projection()->dataManager().data();
-
-    return KisHLineIteratorPixel(m_datamanager.data(), selectionDm, x, y, w, m_d->x, m_d->y);
-}
-
-
 KisHLineIteratorSP KisPaintDevice::createHLineIteratorNG(qint32 x, qint32 y, qint32 w)
 {
     m_d->cache.invalidate();
@@ -865,81 +820,18 @@ KisRectConstIteratorSP KisPaintDevice::createRectConstIteratorNG(const QRect& r)
     return createRectConstIteratorNG(r.x(), r.y(), r.width(), r.height());
 }
 
-KisHLineConstIteratorPixel  KisPaintDevice::createHLineConstIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection) const
+KisRepeatHLineConstIteratorSP KisPaintDevice::createRepeatHLineConstIterator(qint32 x, qint32 y, qint32 w, const QRect& _dataWidth) const
 {
     KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
-    KisDataManager* selectionDm = 0;
 
-    if (selection)
-        selectionDm = const_cast< KisDataManager*>(selection->projection()->dataManager().data());
-
-    return KisHLineConstIteratorPixel(dm, selectionDm, x, y, w, m_d->x, m_d->y);
+    return new KisRepeatHLineConstIteratorNG(dm, x, y, w, m_d->x, m_d->y, _dataWidth);
 }
 
-KisRepeatHLineConstIteratorPixel KisPaintDevice::createRepeatHLineConstIterator(qint32 x, qint32 y, qint32 w, const QRect& _dataWidth, const KisSelection * selection) const
+KisRepeatVLineConstIteratorSP KisPaintDevice::createRepeatVLineConstIterator(qint32 x, qint32 y, qint32 h, const QRect& _dataWidth) const
 {
     KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
-    KisDataManager* selectionDm = 0;
 
-    if (selection)
-        selectionDm = const_cast< KisDataManager*>(selection->projection()->dataManager().data());
-
-    return KisRepeatHLineConstIteratorPixel(dm, selectionDm, x, y, w, m_d->x, m_d->y, _dataWidth);
-}
-
-KisRepeatVLineConstIteratorPixel KisPaintDevice::createRepeatVLineConstIterator(qint32 x, qint32 y, qint32 h, const QRect& _dataWidth, const KisSelection * selection) const
-{
-    KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = const_cast< KisDataManager*>(selection->projection()->dataManager().data());
-
-    return KisRepeatVLineConstIteratorPixel(dm, selectionDm, x, y, h, m_d->x, m_d->y, _dataWidth);
-}
-
-KisVLineIteratorPixel  KisPaintDevice::createVLineIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection)
-{
-    m_d->cache.invalidate();
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = selection->projection()->dataManager().data();
-
-    return KisVLineIteratorPixel(m_datamanager.data(), selectionDm, x, y, h, m_d->x, m_d->y);
-}
-
-KisVLineConstIteratorPixel  KisPaintDevice::createVLineConstIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection) const
-{
-    KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = const_cast< KisDataManager*>(selection->projection()->dataManager().data());
-
-    return KisVLineConstIteratorPixel(dm, selectionDm, x, y, h, m_d->x, m_d->y);
-}
-
-KisRandomAccessorPixel KisPaintDevice::createRandomAccessor(qint32 x, qint32 y, const KisSelection * selection)
-{
-    m_d->cache.invalidate();
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = selection->projection()->dataManager().data();
-
-    return KisRandomAccessorPixel(m_datamanager.data(), selectionDm, x, y, m_d->x, m_d->y);
-}
-
-KisRandomConstAccessorPixel KisPaintDevice::createRandomConstAccessor(qint32 x, qint32 y, const KisSelection * selection) const
-{
-    KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
-    KisDataManager* selectionDm = 0;
-
-    if (selection)
-        selectionDm = const_cast< KisDataManager*>(selection->projection()->dataManager().data());
-
-    return KisRandomConstAccessorPixel(dm, selectionDm, x, y, m_d->x, m_d->y);
+    return new KisRepeatVLineConstIteratorNG(dm, x, y, h, m_d->x, m_d->y, _dataWidth);
 }
 
 KisRandomAccessorSP KisPaintDevice::createRandomAccessorNG(qint32 x, qint32 y)
@@ -955,40 +847,34 @@ KisRandomConstAccessorSP KisPaintDevice::createRandomConstAccessorNG(qint32 x, q
     return new KisRandomAccessor2(dm, x, y, m_d->x, m_d->y, false);
 }
 
-KisRandomSubAccessorPixel KisPaintDevice::createRandomSubAccessor(const KisSelection * selection) const
+KisRandomSubAccessorSP KisPaintDevice::createRandomSubAccessor() const
 {
-    m_d->cache.invalidate();
-    // XXX: shouldn't we use the selection here?
-    Q_UNUSED(selection);
     KisPaintDevice* pd = const_cast<KisPaintDevice*>(this);
-    return KisRandomSubAccessorPixel(pd);
+    return new KisRandomSubAccessor(pd);
 }
 
 void KisPaintDevice::clearSelection(KisSelectionSP selection)
 {
-    QRect r = selection->selectedExactRect();
+    QRect r = selection->selectedExactRect() & m_d->defaultBounds->bounds();
 
     if (r.isValid()) {
 
-        KisHLineIterator devIt = createHLineIterator(r.x(), r.y(), r.width());
-        KisHLineConstIterator selectionIt = selection->projection()->createHLineIterator(r.x(), r.y(), r.width());
+        KisHLineIteratorSP devIt = createHLineIteratorNG(r.x(), r.y(), r.width());
+        KisHLineConstIteratorSP selectionIt = selection->projection()->createHLineIteratorNG(r.x(), r.y(), r.width());
 
         const quint8* defaultPixel_ = defaultPixel();
         bool transparentDefault = (m_d->colorSpace->opacityU8(defaultPixel_) == OPACITY_TRANSPARENT_U8);
         for (qint32 y = 0; y < r.height(); y++) {
 
-            while (!devIt.isDone()) {
+            do {
                 // XXX: Optimize by using stretches
-
-                m_d->colorSpace->applyInverseAlphaU8Mask(devIt.rawData(), selectionIt.rawData(), 1);
-                if (transparentDefault && m_d->colorSpace->opacityU8(devIt.rawData()) == OPACITY_TRANSPARENT_U8) {
-                    memcpy(devIt.rawData(), defaultPixel_, m_d->colorSpace->pixelSize());
+                m_d->colorSpace->applyInverseAlphaU8Mask(devIt->rawData(), selectionIt->oldRawData(), 1);
+                if (transparentDefault && m_d->colorSpace->opacityU8(devIt->rawData()) == OPACITY_TRANSPARENT_U8) {
+                    memcpy(devIt->rawData(), defaultPixel_, m_d->colorSpace->pixelSize());
                 }
-                ++devIt;
-                ++selectionIt;
-            }
-            devIt.nextRow();
-            selectionIt.nextRow();
+            } while (devIt->nextPixel() && selectionIt->nextPixel());
+            devIt->nextRow();
+            selectionIt->nextRow();
         }
         m_datamanager->purge(r.translated(-m_d->x, -m_d->y));
         setDirty(r);
@@ -997,9 +883,9 @@ void KisPaintDevice::clearSelection(KisSelectionSP selection)
 
 bool KisPaintDevice::pixel(qint32 x, qint32 y, QColor *c) const
 {
-    KisHLineConstIteratorPixel iter = createHLineConstIterator(x, y, 1);
+    KisHLineConstIteratorSP iter = createHLineConstIteratorNG(x, y, 1);
 
-    const quint8 *pix = iter.rawData();
+    const quint8 *pix = iter->oldRawData();
 
     if (!pix) return false;
 
@@ -1011,9 +897,9 @@ bool KisPaintDevice::pixel(qint32 x, qint32 y, QColor *c) const
 
 bool KisPaintDevice::pixel(qint32 x, qint32 y, KoColor * kc) const
 {
-    KisHLineConstIteratorPixel iter = createHLineConstIterator(x, y, 1);
+    KisHLineConstIteratorSP iter = createHLineConstIteratorNG(x, y, 1);
 
-    const quint8 *pix = iter.rawData();
+    const quint8 *pix = iter->oldRawData();
 
     if (!pix) return false;
 
@@ -1024,9 +910,9 @@ bool KisPaintDevice::pixel(qint32 x, qint32 y, KoColor * kc) const
 
 bool KisPaintDevice::setPixel(qint32 x, qint32 y, const QColor& c)
 {
-    KisHLineIteratorPixel iter = createHLineIterator(x, y, 1);
+    KisHLineIteratorSP iter = createHLineIteratorNG(x, y, 1);
 
-    colorSpace()->fromQColor(c, iter.rawData());
+    colorSpace()->fromQColor(c, iter->rawData());
     m_d->cache.invalidate();
     return true;
 }
@@ -1034,20 +920,22 @@ bool KisPaintDevice::setPixel(qint32 x, qint32 y, const QColor& c)
 bool KisPaintDevice::setPixel(qint32 x, qint32 y, const KoColor& kc)
 {
     const quint8 * pix;
-    KisHLineIteratorPixel iter = createHLineIterator(x, y, 1);
+    KisHLineIteratorSP iter = createHLineIteratorNG(x, y, 1);
     if (kc.colorSpace() != m_d->colorSpace) {
         KoColor kc2(kc, m_d->colorSpace);
         pix = kc2.data();
-        memcpy(iter.rawData(), pix, m_d->colorSpace->pixelSize());
+        memcpy(iter->rawData(), pix, m_d->colorSpace->pixelSize());
     } else {
         pix = kc.data();
-        memcpy(iter.rawData(), pix, m_d->colorSpace->pixelSize());
+        memcpy(iter->rawData(), pix, m_d->colorSpace->pixelSize());
     }
     m_d->cache.invalidate();
     return true;
 }
 
 
+
+
 qint32 KisPaintDevice::numContiguousColumns(qint32 x, qint32 minY, qint32 maxY) const
 {
     return m_datamanager->numContiguousColumns(x - m_d->x, minY - m_d->y, maxY - m_d->y);
@@ -1089,6 +977,14 @@ void KisPaintDevice::fastBitBlt(KisPaintDeviceSP src, const QRect &rect)
     m_d->cache.invalidate();
 }
 
+void KisPaintDevice::fastBitBltOldData(KisPaintDeviceSP src, const QRect &rect)
+{
+    Q_ASSERT(fastBitBltPossible(src));
+
+    m_datamanager->bitBltOldData(src->dataManager(), rect.translated(-m_d->x, -m_d->y));
+    m_d->cache.invalidate();
+}
+
 void KisPaintDevice::fastBitBltRough(KisPaintDeviceSP src, const QRect &rect)
 {
     Q_ASSERT(fastBitBltPossible(src));
@@ -1097,6 +993,14 @@ void KisPaintDevice::fastBitBltRough(KisPaintDeviceSP src, const QRect &rect)
     m_d->cache.invalidate();
 }
 
+void KisPaintDevice::fastBitBltRoughOldData(KisPaintDeviceSP src, const QRect &rect)
+{
+    Q_ASSERT(fastBitBltPossible(src));
+
+    m_datamanager->bitBltRoughOldData(src->dataManager(), rect.translated(-m_d->x, -m_d->y));
+    m_d->cache.invalidate();
+}
+
 void KisPaintDevice::readBytes(quint8 * data, qint32 x, qint32 y, qint32 w, qint32 h) const
 {
     m_datamanager->readBytes(data, x - m_d->x, y - m_d->y, w, h);
