@@ -30,7 +30,7 @@
 #include "kis_types.h"
 #include "kis_global.h"
 #include "kis_shared.h"
-#include "kis_iterators_pixel.h"
+#include "kis_default_bounds_base.h"
 
 #include <krita_export.h>
 
@@ -50,7 +50,7 @@ class KisHLineIteratorNG;
 class KisRandomSubAccessorPixel;
 class KisDataManager;
 class KisSelectionComponent;
-class KisDefaultBounds;
+
 
 typedef KisSharedPtr<KisDataManager> KisDataManagerSP;
 
@@ -87,7 +87,7 @@ public:
      * @param defaultBounds boundaries of the device in case it is empty
      * @param name for debugging purposes
      */
-    KisPaintDevice(KisNodeWSP parent, const KoColorSpace * colorSpace, KisDefaultBounds * defaultBounds = 0, const QString& name = QString());
+    KisPaintDevice(KisNodeWSP parent, const KoColorSpace * colorSpace, KisDefaultBoundsBaseSP defaultBounds = 0, const QString& name = QString());
 
     KisPaintDevice(const KisPaintDevice& rhs);
     virtual ~KisPaintDevice();
@@ -127,12 +127,12 @@ public:
      * set the default bounds for the paint device when
      * the default pixel in not completely transarent
      */
-    virtual void setDefaultBounds(KisDefaultBounds * bounds);
+    virtual void setDefaultBounds(KisDefaultBoundsBaseSP bounds);
 
      /**
      * the default bounds rect of the paint device
      */
-    KisDefaultBounds * defaultBounds() const;
+    KisDefaultBoundsBaseSP defaultBounds() const;
 
     /**
      * Moves the device to these new coordinates (so no incremental move or so)
@@ -197,9 +197,6 @@ public:
      */
     virtual QRect exactBounds() const;
 
-    /// Convience method for the above
-    KDE_DEPRECATED void exactBounds(qint32 &x, qint32 &y, qint32 &w, qint32 &h) const;
-
     /**
      * Returns a rough approximation of region covered by device.
      * For tiled data manager, it region will consist of a number
@@ -222,6 +219,13 @@ public:
      */
     virtual void clear();
 
+    /**
+     * Clear the given rectangle to transparent black. The paint device will expand to
+     * contain the given rect.
+     */
+    void clear(const QRect & rc);
+
+
     /**
      * Sets the default pixel. New data will be initialised with this pixel. The pixel is copied: the
      * caller still owns the pointer and needs to delete it to avoid memory leaks.
@@ -233,12 +237,6 @@ public:
      */
     const quint8 *defaultPixel() const;
 
-    /**
-     * Clear the given rectangle to transparent black. The paint device will expand to
-     * contain the given rect.
-     */
-    void clear(const QRect & rc);
-
     /**
      * Fill the given rectangle with the given pixel. The paint device will expand to
      * contain the given rect.
@@ -309,6 +307,11 @@ protected:
      */
     void fastBitBlt(KisPaintDeviceSP src, const QRect &rect);
 
+    /**
+     * The same as \ref fastBitBlt() but reads old data
+     */
+    void fastBitBltOldData(KisPaintDeviceSP src, const QRect &rect);
+
     /**
      * Clones rect from another paint device in a rough and fast way.
      * All the tiles touched by rect will be shared, between both
@@ -321,6 +324,11 @@ protected:
      */
     void fastBitBltRough(KisPaintDeviceSP src, const QRect &rect);
 
+    /**
+     * The same as \ref fastBitBltRough() but reads old data
+     */
+    void fastBitBltRoughOldData(KisPaintDeviceSP src, const QRect &rect);
+
 public:
     /**
      * Read the bytes representing the rectangle described by x, y, w, h into
@@ -446,7 +454,6 @@ public:
      * @param rect: only this rect will be used for the thumbnail
      *
      */
-
     virtual KisPaintDeviceSP createThumbnailDevice(qint32 w, qint32 h, const KisSelection *selection = 0, QRect rect = QRect()) const;
 
     /**
@@ -560,35 +567,6 @@ public:
 
 public:
 
-    /**
-     * Create an iterator over a rectangle section of a paint device, the path followed by
-     * the iterator is not guaranteed, it is optimized for speed, which means that you shouldn't
-     * use this type of iterator if you are combining two differents layers.
-     * @param w width
-     * @param h height
-     * @param selection an up-to-date selection that has the same origin as the paint device
-     * @return an iterator which points to the first pixel of an rectangle
-     */
-    KDE_DEPRECATED KisRectIteratorPixel createRectIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection = 0);
-
-    /**
-     * Create an iterator over a rectangle section of a paint device, the path followed by
-     * the iterator is not guaranteed, it is optimized for speed, which means that you shouldn't
-     * use this type of iterator if you are combining two differents layers.
-     * @param w width
-     * @param h height
-     * @param selection an up-to-date selection that has the same origin as the paint device* @return an iterator which points to the first pixel of an rectangle, this iterator
-     * does not allow to change the pixel values
-     */
-    KDE_DEPRECATED  KisRectConstIteratorPixel createRectConstIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection = 0) const;
-
-    /**
-     * @param selection an up-to-date selection that has the same origin as the paint device
-     * @return an iterator which points to the first pixel of a horizontal line, this iterator
-     * does not allow to change the pixel values
-     */
-    KDE_DEPRECATED KisHLineConstIteratorPixel createHLineConstIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection = 0) const;
-
     KisHLineIteratorSP createHLineIteratorNG(qint32 x, qint32 y, qint32 w);
 
     KisHLineConstIteratorSP createHLineConstIteratorNG(qint32 x, qint32 y, qint32 w) const;
@@ -613,57 +591,20 @@ public:
      *
      * @param rc indicates the rectangle that truly contains data
      */
-    KisRepeatHLineConstIteratorPixel createRepeatHLineConstIterator(qint32 x, qint32 y, qint32 w, const QRect& _dataWidth, const KisSelection * selection = 0) const;
+    KisRepeatHLineConstIteratorSP createRepeatHLineConstIterator(qint32 x, qint32 y, qint32 w, const QRect& _dataWidth) const;
     /**
      * Create an iterator that will "artificially" extend the paint device with the
      * value of the border when trying to access values outside the range of data.
      *
      * @param rc indicates the rectangle that trully contains data
      */
-    KisRepeatVLineConstIteratorPixel createRepeatVLineConstIterator(qint32 x, qint32 y, qint32 h, const QRect& _dataWidth, const KisSelection * selection = 0) const;
-
-    /**
-    * @param selection an up-to-date selection that has the same origin as the paint device
-     * @return an iterator which points to the first pixel of a horizontal line
-     */
-    KDE_DEPRECATED KisHLineIteratorPixel createHLineIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection = 0);
-
-    /**
-     * @param selection an up-to-date selection that has the same origin as the paint device
-     * This function return an iterator which points to the first pixel of a vertical line
-     */
-    KDE_DEPRECATED KisVLineIteratorPixel createVLineIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection = 0);
-
-    /**
-     * @param selection an up-to-date selection that has the same origin as the paint device
-     * This function return an iterator which points to the first pixel of a vertical line
-     */
-    KDE_DEPRECATED KisVLineConstIteratorPixel createVLineConstIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection = 0) const;
-
-    /**
-     * This function creates a random accessor which allow to randomly access any pixels on
-     * the paint device.
-     * <b>Note:</b> random access is way slower than iterators, always use iterators whenever
-     * you can.
-     * @param x, y starting point of the accessor
-     * @param selection an up-to-date selection that has the same origin as the paint device
-     */
-    KDE_DEPRECATED KisRandomAccessorPixel createRandomAccessor(qint32 x, qint32 y, const KisSelection * selection = 0);
-
-    /**
-     * This function creates a random accessor which allow to randomly access any pixels on
-     * the paint device.
-     * <b>Note:</b> random access is way slower than iterators, always use iterators whenever
-     * you can.
-     * @param selection an up-to-date selection that has the same origin as the paint device
-     */
-    KDE_DEPRECATED KisRandomConstAccessorPixel createRandomConstAccessor(qint32 x, qint32 y, const KisSelection * selection = 0) const;
+    KisRepeatVLineConstIteratorSP createRepeatVLineConstIterator(qint32 x, qint32 y, qint32 h, const QRect& _dataWidth) const;
 
     /**
      * This function create a random accessor which can easily access to sub pixel values.
      * @param selection an up-to-date selection that has the same origin as the paint device
      */
-    KisRandomSubAccessorPixel createRandomSubAccessor(const KisSelection * selection = 0) const;
+    KisRandomSubAccessorSP createRandomSubAccessor() const;
 
 
     /** Clear the selected pixels from the paint device */
@@ -691,7 +632,7 @@ private:
     KisPaintDevice& operator=(const KisPaintDevice&);
     void init(KisDataManagerSP explicitDataManager,
               const KoColorSpace *colorSpace,
-              KisDefaultBounds * defaultBounds,
+              KisDefaultBoundsBaseSP defaultBounds,
               KisNodeWSP parent, const QString& name);
 
     // Only KisPainter is allowed to have access to these low-level methods
@@ -721,6 +662,10 @@ private:
      */
     QVector<qint32> channelSizes();
 
+private:
+    friend class KisSelectionTest;
+    KisNodeWSP parentNode() const;
+
 private:
     KisDataManagerSP m_datamanager;
 
