@@ -37,6 +37,7 @@
 #include "kis_image.h"
 #include "kis_fill_painter.h"
 #include "kis_outline_generator.h"
+#include <kis_iterator_ng.h>
 
 struct KisPixelSelection::Private {
 };
@@ -70,15 +71,13 @@ KisPaintDeviceSP KisPixelSelection::createThumbnailDevice(qint32 w, qint32 h, co
         KisPaintDevice::createThumbnailDevice(w, h, selection, rect);
 
     QRect bounds = dev->exactBounds();
-    KisHLineIteratorPixel it = dev->createHLineIterator(bounds.x(), bounds.y(), bounds.width());
+    KisHLineIteratorSP it = dev->createHLineIteratorNG(bounds.x(), bounds.y(), bounds.width());
 
     for (int y2 = bounds.y(); y2 < bounds.height() + bounds.y(); ++y2) {
-
-        while (!it.isDone()) {
-            *(it.rawData()) = MAX_SELECTED - *(it.rawData());
-            ++it;
-        }
-        it.nextRow();
+        do {
+            *(it->rawData()) = MAX_SELECTED - *(it->rawData());
+        } while (it->nextPixel());
+        it->nextRow();
     }
     return dev;
 }
@@ -117,58 +116,51 @@ void KisPixelSelection::applySelection(KisPixelSelectionSP selection, SelectionA
 void KisPixelSelection::addSelection(KisPixelSelectionSP selection)
 {
     QRect r = selection->selectedRect();
-    KisHLineIteratorPixel dst = createHLineIterator(r.x(), r.y(), r.width());
-    KisHLineConstIteratorPixel src = selection->createHLineConstIterator(r.x(), r.y(), r.width());
+    KisHLineIteratorSP dst = createHLineIteratorNG(r.x(), r.y(), r.width());
+    KisHLineConstIteratorSP src = selection->createHLineConstIteratorNG(r.x(), r.y(), r.width());
     for (int i = 0; i < r.height(); ++i) {
-        while (!src.isDone()) {
-            if (*src.rawData() + *dst.rawData() < MAX_SELECTED)
-                *dst.rawData() = *src.rawData() + *dst.rawData();
+        do {
+            if (*src->oldRawData() + *dst->rawData() < MAX_SELECTED)
+                *dst->rawData() = *src->oldRawData() + *dst->rawData();
             else
-                *dst.rawData() = MAX_SELECTED;
-            ++src;
-            ++dst;
-        }
-        dst.nextRow();
-        src.nextRow();
-    }
+                *dst->rawData() = MAX_SELECTED;
 
+        } while (src->nextPixel() && dst->nextPixel());
+        dst->nextRow();
+        src->nextRow();
+    }
 }
 
 void KisPixelSelection::subtractSelection(KisPixelSelectionSP selection)
 {
     QRect r = selection->selectedRect();
-    KisHLineIteratorPixel dst = createHLineIterator(r.x(), r.y(), r.width());
-    KisHLineConstIteratorPixel src = selection->createHLineConstIterator(r.x(), r.y(), r.width());
+    KisHLineIteratorSP dst = createHLineIteratorNG(r.x(), r.y(), r.width());
+    KisHLineConstIteratorSP src = selection->createHLineConstIteratorNG(r.x(), r.y(), r.width());
     for (int i = 0; i < r.height(); ++i) {
-        while (!src.isDone()) {
-            if (*dst.rawData() - *src.rawData() > MIN_SELECTED)
-                *dst.rawData() = *dst.rawData() - *src.rawData();
+        do {
+            if (*dst->rawData() - *src->oldRawData() > MIN_SELECTED)
+                *dst->rawData() = *dst->rawData() - *src->oldRawData();
             else
-                *dst.rawData() = MIN_SELECTED;
-            ++src;
-            ++dst;
-        }
-        dst.nextRow();
-        src.nextRow();
-    }
+                *dst->rawData() = MIN_SELECTED;
 
+        } while (src->nextPixel() && dst->nextPixel());
+        dst->nextRow();
+        src->nextRow();
+    }
 }
 
 void KisPixelSelection::intersectSelection(KisPixelSelectionSP selection)
 {
     QRect r = selection->selectedRect().united(selectedRect());
 
-    KisHLineIteratorPixel dst = createHLineIterator(r.x(), r.y(), r.width());
-    KisHLineConstIteratorPixel src = selection->createHLineConstIterator(r.x(), r.y(), r.width());
+    KisHLineIteratorSP dst = createHLineIteratorNG(r.x(), r.y(), r.width());
+    KisHLineConstIteratorSP src = selection->createHLineConstIteratorNG(r.x(), r.y(), r.width());
     for (int i = 0; i < r.height(); ++i) {
-        while (!src.isDone()) {
-            *dst.rawData() = qMin(*dst.rawData(), *src.rawData());
-
-            ++src;
-            ++dst;
-        }
-        dst.nextRow();
-        src.nextRow();
+        do {
+            *dst->rawData() = qMin(*dst->rawData(), *src->oldRawData());
+        }  while (src->nextPixel() && dst->nextPixel());
+        dst->nextRow();
+        src->nextRow();
     }
 }
 
@@ -196,12 +188,24 @@ void KisPixelSelection::invert()
     // unselected but existing pixels need to be inverted too
     QRect rc = region().boundingRect();
 
-    KisRectIterator it = createRectIterator(rc.x(), rc.y(), rc.width(), rc.height());
-    while (! it.isDone()) {
-        *(it.rawData()) = MAX_SELECTED - *(it.rawData());
-        ++it;
+    if (!rc.isEmpty()) {
+#if 0
+        quint8 *bytes = new quint8[rc.width()];
+        for(int row = rc.y(); row < rc.height(); ++row) {
+            readBytes(bytes, rc.x(), row, rc.width(), 1);
+            for (int i = 0; i < rc.width(); ++i) {
+                bytes[i] = MAX_SELECTED - bytes[i];
+            }
+            writeBytes(bytes, rc.x(), row, rc.width(), 1);
+        }
+        delete []bytes;
+#else
+        KisRectIteratorSP it = createRectIteratorNG(rc.x(), rc.y(), rc.width(), rc.height());
+        do {
+            *(it->rawData()) = MAX_SELECTED - *(it->rawData());
+        } while (it->nextPixel());
+#endif
     }
-
     quint8 defPixel = MAX_SELECTED - *defaultPixel();
     setDefaultPixel(&defPixel);
 }
