@@ -33,7 +33,7 @@ KAboutData * newKritaAboutData()
                                             ki18n("Digital Painting for Artists"),
                                             KAboutData::License_GPL,
                                             ki18n("(c) 1999-2012 The Krita team.\n"),
-                                            ki18n("This release of Krita is dedicated to the memory of Jean Giraud - Moebius, whose work will always be an inspiration."),
+                                            KLocalizedString(),
                                             "http://www.krita.org",
                                             "submit@bugs.kde.org");
     aboutData->addAuthor(ki18n("Adrian Page"), KLocalizedString(), "Adrian.Page@tesco.net");
@@ -43,7 +43,7 @@ KAboutData * newKritaAboutData()
     aboutData->addAuthor(ki18n("Boudewijn Rempt"), ki18n("Maintainer"), "boud@valdyas.org", "http://www.valdyas.org/fading/index.cgi");
     aboutData->addAuthor(ki18n("David Revoy"), ki18n("Brush and palette set"), "", "http://http://www.davidrevoy.com/");
     aboutData->addAuthor(ki18n("Carsten Pfeiffer"), KLocalizedString(), "carpdjih@cetus.zrz.tu-berlin.de");
-    aboutData->addAuthor(ki18n("Casper Boemann"), KLocalizedString(), "cbr@boemann.dk");
+    aboutData->addAuthor(ki18n("C. Boemann"), KLocalizedString(), "cbo@boemann.dk");
     aboutData->addAuthor(ki18n("Clarence Dang"), KLocalizedString(), "dang@kde.org");
     aboutData->addAuthor(ki18n("Cyrille Berger"), KLocalizedString(), "cyb@lepi.org");
     aboutData->addAuthor(ki18n("Dirk Schoenberger"), KLocalizedString(), "dirk.schoenberger@sz-online.de");
