@@ -47,6 +47,26 @@
 #include "kis_statusbar.h"
 #include "kis_config.h"
 
+class KisZoomController : public KoZoomController
+{
+public:
+    KisZoomController(KoCanvasController *co, KisCoordinatesConverter *zh, KActionCollection *actionCollection, KoZoomAction::SpecialButtons specialButtons, QObject *parent)
+        : KoZoomController(co, zh, actionCollection, specialButtons, parent),
+          m_converter(zh)
+    {
+    }
+
+protected:
+    QSize documentToViewport(const QSizeF &size) {
+        QRectF docRect(QPointF(), size);
+        return m_converter->documentToWidget(docRect).toRect().size();
+    }
+
+private:
+    KisCoordinatesConverter *m_converter;
+};
+
+
 KisZoomManager::KisZoomManager(KisView2 * view, KoZoomHandler * zoomHandler,
                                KoCanvasController * canvasController)
         : m_view(view)
@@ -72,8 +92,11 @@ void KisZoomManager::setup(KActionCollection * actionCollection)
     KoZoomMode::setMinimumZoom(0.125);
     KoZoomMode::setMaximumZoom(64.0);
 
+    KisCoordinatesConverter *converter =
+        dynamic_cast<KisCoordinatesConverter*>(m_zoomHandler);
+
     KisConfig cfg;
-    m_zoomController = new KoZoomController(m_canvasController, m_zoomHandler, actionCollection, KoZoomAction::AspectMode, this);
+    m_zoomController = new KisZoomController(m_canvasController, converter, actionCollection, KoZoomAction::AspectMode, this);
     m_zoomHandler->setZoomMode(KoZoomMode::ZOOM_PIXELS);
     m_zoomHandler->setZoom(1.0);
 
@@ -148,9 +171,8 @@ void KisZoomManager::setup(KActionCollection * actionCollection)
 
 void KisZoomManager::mousePositionChanged(const QPoint &pos)
 {
-    // "widget-to-postprocessed-flake"
-    QPoint canvasOffset(m_canvasController->canvasOffsetX(), m_canvasController->canvasOffsetY());
-    QPoint viewPos = pos - m_canvasController->canvas()->documentOrigin() - canvasOffset;
+    QPoint canvasShift = m_view->canvasBase()->coordinatesConverter()->flakeToWidget(QPointF(m_canvasController->canvasOffsetX(), m_canvasController->canvasOffsetY())).toPoint();
+    QPoint viewPos = pos - canvasShift;
 
     m_horizontalRuler->updateMouseCoordinate(viewPos.x());
     m_verticalRuler->updateMouseCoordinate(viewPos.y());
@@ -177,13 +199,11 @@ void KisZoomManager::slotZoomChanged(KoZoomMode::Mode mode, qreal zoom)
     Q_UNUSED(zoom);
 
     m_view->canvasBase()->notifyZoomChanged();
-    m_canvasController->pan(m_view->canvasBase()->coordinatesConverter()->updateOffsetAfterTransform());
 }
 
 void KisZoomManager::slotScrollAreaSizeChanged()
 {
-    QSize widgetSize = m_view->canvasBase()->coordinatesConverter()->imageRectInWidgetPixels().toAlignedRect().size();
-    m_canvasController->updateDocumentSize(widgetSize, true);
+    pageOffsetChanged();
     updateGUI();
 }
 
@@ -203,8 +223,11 @@ void KisZoomManager::changeAspectMode(bool aspectMode)
 
 void KisZoomManager::pageOffsetChanged()
 {
-    m_horizontalRuler->setOffset(m_canvasController->canvasOffsetX() + m_view->canvasBase()->documentOrigin().x());
-    m_verticalRuler->setOffset(m_canvasController->canvasOffsetY() + m_view->canvasBase()->documentOrigin().y());
+    QRectF widgetRect = m_view->canvasBase()->coordinatesConverter()->imageRectInWidgetPixels();
+    QPoint canvasShift = widgetRect.topLeft().toPoint();
+
+    m_horizontalRuler->setOffset(canvasShift.x());
+    m_verticalRuler->setOffset(canvasShift.y());
 }
 
 void KisZoomManager::zoomTo100()
