@@ -21,7 +21,7 @@
 **
 ****************************************************************************/
 
-#include <QtGui/QtGui>
+#include <QtGui>
 
 #include "modeltest.h"
 
