@@ -39,13 +39,14 @@ KoShapePaintingContext::KoShapePaintingContext(KoCanvasBase *canvas, bool forPri
     if (forPrint) {
         showTextShapeOutlines = false;
         showFormattingCharacters = false;
+        showTableBorders = false;
     } else {
         showTextShapeOutlines = rm->boolResource(KoCanvasResourceManager::ShowTextShapeOutlines);
-    }
-    if (rm->hasResource(KoCanvasResourceManager::ShowTableBorders)) {
-        showTableBorders = rm->boolResource(KoCanvasResourceManager::ShowTableBorders);
-    } else {
-        showTableBorders = true;
+        if (rm->hasResource(KoCanvasResourceManager::ShowTableBorders)) {
+            showTableBorders = rm->boolResource(KoCanvasResourceManager::ShowTableBorders);
+        } else {
+            showTableBorders = true;
+        }
     }
     showSpellChecking = !forPrint;
     showSelections = !forPrint;
