@@ -20,7 +20,7 @@
 #include "reportsection.h"
 #include "KoReportDesigner.h"
 #include "KoReportDesignerItemBase.h"
-
+#include "krutils.h"
 #include "KoReportPluginInterface.h"
 #include "KoReportPluginManager.h"
 #include "KoReportDesignerItemRectBase.h"
@@ -149,9 +149,7 @@ void ReportSection::slotResizeBarDragged(int delta)
 
 void ReportSection::buildXML(QDomDocument &doc, QDomElement &section)
 {
-    QString un = m_sectionData->m_height->option("unit", "cm").toString();
-
-    section.setAttribute("svg:height", KoUnit::fromSymbol(un).toUserStringValue(m_sectionData->m_height->value().toDouble()) + un);
+    KRUtils::setAttribute(section, "svg:height", m_sectionData->m_height->value().toDouble());
     section.setAttribute("fo:background-color", m_sectionData->backgroundColor().name());
 
     // now get a list of all the QGraphicsItems on this scene and output them.
