@@ -25,8 +25,8 @@
 #include <QTextStream>
 #include <QtScript>
 #include <QtTest>
+#include <QApplication>
 
-#include <KoStyleManager.h>
 #include <KoOdfStylesReader.h>
 #include <KoStore.h>
 #include <KoOdfStylesReader.h>
@@ -1007,7 +1007,7 @@ QTextDocument *TestLoading::documentFromOdt(const QString &odt)
     KoXmlElement realBody(KoXml::namedItemNS(content, KoXmlNS::office, "body"));
     KoXmlElement body = KoXml::namedItemNS(realBody, KoXmlNS::office, "text");
 
-    KoStyleManager *styleManager = new KoStyleManager;
+    KoStyleManager *styleManager = new KoStyleManager(0);
     KoChangeTracker *changeTracker = new KoChangeTracker;
 
     KoOdfLoadingContext odfLoadingContext(odfReadStore.styles(), odfReadStore.store(), *componentData);
@@ -1085,7 +1085,7 @@ QString TestLoading::documentToOdt(QTextDocument *document)
     }
 
     if(!KoTextDocument(document).inlineTextObjectManager()) {
-        KoStyleManager *styleManager = new KoStyleManager;
+        KoStyleManager *styleManager = new KoStyleManager(0);
         KoTextDocument(document).setStyleManager(styleManager);
         KoChangeTracker* changeTracker = new KoChangeTracker;
         KoTextDocument(document).setChangeTracker(changeTracker);
