@@ -32,11 +32,15 @@
 #include "KoTableCellStyle.h"
 #include "KoSectionStyle.h"
 #include "ChangeFollower.h"
+#include "commands/ChangeStylesMacroCommand.h"
 #include "KoTextDocument.h"
 
 #include <KoGenStyle.h>
 #include <KoGenStyles.h>
 #include <KoShapeSavingContext.h>
+#include <KoTextSharedSavingData.h>
+
+#include <kundo2stack.h>
 
 #include <QTimer>
 #include <QUrl>
@@ -52,7 +56,7 @@
 class KoStyleManager::Private
 {
 public:
-    Private() : updateTriggered(false), defaultCharacterStyle(0), defaultParagraphStyle(0), defaultListStyle(0), outlineStyle(0)
+    Private() : defaultCharacterStyle(0), defaultParagraphStyle(0), defaultListStyle(0), defaultOutlineStyle(0), outlineStyle(0), undoStack(0), changeCommand(0)
     {
     }
     ~Private() {
@@ -72,17 +76,19 @@ public:
     QHash<int, KoParagraphStyle *> unusedParagraphStyles;
     QList<ChangeFollower*> documentUpdaterProxies;
 
-    bool updateTriggered;
-    QList<int> updateQueue;
 
     KoCharacterStyle *defaultCharacterStyle;
     KoParagraphStyle *defaultParagraphStyle;
     KoListStyle *defaultListStyle;
+    KoListStyle *defaultOutlineStyle;
     KoListStyle *outlineStyle;
     QList<int> defaultToCEntriesStyleId;
+    QList<int> defaultBibEntriesStyleId;
     KoOdfNotesConfiguration *footNotesConfiguration;
     KoOdfNotesConfiguration *endNotesConfiguration;
     KoOdfBibliographyConfiguration *bibliographyConfiguration;
+    KUndo2Stack *undoStack;
+    ChangeStylesMacroCommand *changeCommand;
 };
 
 // static
@@ -103,12 +109,22 @@ KoStyleManager::KoStyleManager(QObject *parent)
 
     //TODO: also use the defaultstyles.xml mechanism. see KoOdfLoadingContext and KoTextSharedLoadingData
     d->defaultListStyle = new KoListStyle(this);
-    KoListLevelProperties llp;
-    llp.setLevel(1);
-    llp.setStartValue(1);
-    llp.setStyle(KoListStyle::DecimalItem);
-    llp.setListItemSuffix(".");
-    d->defaultListStyle->setLevelProperties(llp);
+    const int margin = 10; // we specify the margin for the default list style(Note: Even ChangeListCommand has this value)
+    const int maxListLevel = 10;
+    for (int level = 1; level <= maxListLevel; level++) {
+        KoListLevelProperties llp;
+        llp.setLevel(level);
+        llp.setStartValue(1);
+        llp.setStyle(KoListStyle::DecimalItem);
+        llp.setListItemSuffix(".");
+        llp.setAlignmentMode(true);
+        llp.setLabelFollowedBy(KoListStyle::ListTab);
+        llp.setTabStopPosition(margin*(level+2));
+        llp.setMargin(margin*(level+1));
+        llp.setTextIndent(margin);
+
+        d->defaultListStyle->setLevelProperties(llp);
+    }
 
     //default styles for ToCs
     int maxOutLineLevel = 10;
@@ -120,6 +136,13 @@ KoStyleManager::KoStyleManager(QObject *parent)
         d->defaultToCEntriesStyleId.append(style->styleId());
     }
 
+    for (int typeIndex = 0; typeIndex < KoOdfBibliographyConfiguration::bibTypes.size(); typeIndex++) {
+        KoParagraphStyle *style = new KoParagraphStyle();
+        style->setName("Bibliography " + KoOdfBibliographyConfiguration::bibTypes.at(typeIndex));
+        add(style);
+        d->defaultBibEntriesStyleId.append(style->styleId());
+    }
+
     d->footNotesConfiguration = 0;
     d->endNotesConfiguration = 0;
     d->bibliographyConfiguration = 0;
@@ -130,22 +153,37 @@ KoStyleManager::~KoStyleManager()
     delete d;
 }
 
+void KoStyleManager::setUndoStack(KUndo2Stack *undoStack)
+{
+    d->undoStack = undoStack;
+}
+
 void KoStyleManager::saveOdfDefaultStyles(KoShapeSavingContext &context)
 {
     KoGenStyle pstyle(KoGenStyle::ParagraphStyle, "paragraph");
     pstyle.setDefaultStyle(true);
     d->defaultParagraphStyle->saveOdf(pstyle, context);
-    context.mainStyles().insert(pstyle);
+    if (!pstyle.isEmpty()) {
+        context.mainStyles().insert(pstyle);
+    }
 
     KoGenStyle tstyle(KoGenStyle::TextStyle, "text");
     tstyle.setDefaultStyle(true);
     d->defaultCharacterStyle->saveOdf(tstyle);
-    context.mainStyles().insert(tstyle);
+    if (!tstyle.isEmpty()) {
+        context.mainStyles().insert(tstyle);
+    }
 
 }
 
 void KoStyleManager::saveOdf(KoShapeSavingContext &context)
 {
+    KoTextSharedSavingData *textSharedSavingData = 0;
+    if (!(textSharedSavingData = dynamic_cast<KoTextSharedSavingData *>(context.sharedData(KOTEXT_SHARED_SAVING_ID)))) {
+        textSharedSavingData = new KoTextSharedSavingData;
+        context.addSharedData(KOTEXT_SHARED_SAVING_ID, textSharedSavingData);
+    }
+
     saveOdfDefaultStyles(context);
 
     // don't save character styles that are already saved as part of a paragraph style
@@ -162,6 +200,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         KoGenStyle style(KoGenStyle::ParagraphStyle, "paragraph");
         paragraphStyle->saveOdf(style, context);
         QString newName = context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
+        textSharedSavingData->setStyleName(paragraphStyle->styleId(), newName);
         savedNames.insert(paragraphStyle, newName);
     }
 
@@ -185,7 +224,8 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
 
         KoGenStyle style(KoGenStyle::ParagraphStyle, "text");
         characterStyle->saveOdf(style);
-        context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
+        QString newName = context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
+        textSharedSavingData->setStyleName(characterStyle->styleId(), newName);
     }
 
     foreach(KoListStyle *listStyle, d->listStyles) {
@@ -198,6 +238,8 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         KoGenStyle style(KoGenStyle::ListStyle);
         listStyle->saveOdf(style, context);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
+        QString newName = context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
+        textSharedSavingData->setStyleName(listStyle->styleId(), newName);
     }
 
     foreach(KoTableStyle *tableStyle, d->tableStyles) {
@@ -205,7 +247,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         if (name.isEmpty())
             name = 'T'; //TODO is this correct?
 
-        KoGenStyle style(KoGenStyle::TableStyle);
+        KoGenStyle style(KoGenStyle::TableStyle, "table");
         tableStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
@@ -215,7 +257,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         if (name.isEmpty())
             name = 'T'; //TODO is this correct?
 
-        KoGenStyle style(KoGenStyle::TableColumnStyle);
+        KoGenStyle style(KoGenStyle::TableColumnStyle, "table-column");
         tableColumnStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
@@ -225,7 +267,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         if (name.isEmpty())
             name = 'T'; //TODO is this correct?
 
-        KoGenStyle style(KoGenStyle::TableRowStyle);
+        KoGenStyle style(KoGenStyle::TableRowStyle, "table-row");
         tableRowStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
@@ -235,7 +277,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         if (name.isEmpty())
             name = "T."; //TODO is this correct?
 
-        KoGenStyle style(KoGenStyle::TableCellStyle);
+        KoGenStyle style(KoGenStyle::TableCellStyle, "table-cell");
         tableCellStyle->saveOdf(style, context);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
@@ -245,7 +287,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         if (name.isEmpty())
             name = "T."; //TODO is this correct?
 
-        KoGenStyle style(KoGenStyle::SectionStyle);
+        KoGenStyle style(KoGenStyle::SectionStyle, "section");
         sectionStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
@@ -396,48 +438,80 @@ void KoStyleManager::setBibliographyConfiguration(KoOdfBibliographyConfiguration
 
 void KoStyleManager::remove(KoCharacterStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->charStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
 
 void KoStyleManager::remove(KoParagraphStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->paragStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
 
 void KoStyleManager::remove(KoListStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->listStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
 
 void KoStyleManager::remove(KoTableStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->tableStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
 
 void KoStyleManager::remove(KoTableColumnStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->tableColumnStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
 
 void KoStyleManager::remove(KoTableRowStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->tableRowStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
 
 void KoStyleManager::remove(KoTableCellStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->tableCellStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
 
 void KoStyleManager::remove(KoSectionStyle *style)
 {
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     if (d->sectionStyles.remove(style->styleId()))
         emit styleRemoved(style);
 }
@@ -447,101 +521,133 @@ void KoStyleManager::remove(ChangeFollower *cf)
     d->documentUpdaterProxies.removeAll(cf);
 }
 
-void KoStyleManager::alteredStyle(const KoParagraphStyle *style)
+void KoStyleManager::alteredStyle(const KoParagraphStyle *newStyle)
 {
-    Q_ASSERT(style);
-    int id = style->styleId();
+    Q_ASSERT(newStyle);
+    if (!newStyle || !d->changeCommand) {
+        return;
+    }
+
+    int id = newStyle->styleId();
     if (id <= 0) {
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (! d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
+
+    KoParagraphStyle *style = paragraphStyle(id);
+    if (style != newStyle) {
+        d->changeCommand->origStyle(style->clone());
+        d->changeCommand->changedStyle(newStyle->clone());
+    }
 
     // check if anyone that uses 'style' as a parent needs to be flagged as changed as well.
-    foreach(KoParagraphStyle *ps, d->paragStyles) {
+    foreach(const KoParagraphStyle *ps, d->paragStyles) {
         if (ps->parentStyle() == style)
-            alteredStyle(ps);
+            alteredStyle(ps); //since it's our own copy it will only be flagged
     }
 }
 
-void KoStyleManager::alteredStyle(const KoCharacterStyle *style)
+void KoStyleManager::alteredStyle(const KoCharacterStyle *newStyle)
 {
-    Q_ASSERT(style);
-    int id = style->styleId();
+    Q_ASSERT(newStyle);
+    if (!newStyle || !d->changeCommand) {
+        return;
+    }
+
+    int id = newStyle->styleId();
     if (id <= 0) {
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (! d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
+
+    KoCharacterStyle *style = characterStyle(id);
+    if (style != newStyle) {
+        d->changeCommand->origStyle(style->clone());
+        d->changeCommand->changedStyle(newStyle->clone());
+    }
+
+    // check if anyone that uses 'style' as a parent needs to be flagged as changed as well.
+    foreach(const KoCharacterStyle *cs, d->charStyles) {
+        if (cs->parentStyle() == style)
+            alteredStyle(cs); //since it's our own copy it will only be flagged
+    }
 }
 
 void KoStyleManager::alteredStyle(const KoListStyle *style)
 {
     Q_ASSERT(style);
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     int id = style->styleId();
     if (id <= 0) {
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (!d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableStyle *style)
 {
     Q_ASSERT(style);
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     int id = style->styleId();
     if (id <= 0) {
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (!d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableColumnStyle *style)
 {
     Q_ASSERT(style);
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     int id = style->styleId();
     if (id <= 0) {
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (!d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableRowStyle *style)
 {
     Q_ASSERT(style);
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     int id = style->styleId();
     if (id <= 0) {
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (!d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableCellStyle *style)
 {
     Q_ASSERT(style);
+    if (!style || !d->changeCommand) {
+        return;
+    }
+
     int id = style->styleId();
     if (id <= 0) {
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (!d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
 }
 
 void KoStyleManager::alteredStyle(const KoSectionStyle *style)
@@ -552,30 +658,28 @@ void KoStyleManager::alteredStyle(const KoSectionStyle *style)
         kWarning(32500) << "alteredStyle received from a non registered style!";
         return;
     }
-    if (!d->updateQueue.contains(id))
-        d->updateQueue.append(id);
-    requestFireUpdate();
+    d->changeCommand->changedStyle(id);
 }
 
-void KoStyleManager::updateAlteredStyles()
+void KoStyleManager::beginEdit()
 {
-    foreach(ChangeFollower *cf, d->documentUpdaterProxies) {
-        cf->processUpdates(d->updateQueue);
+    d->changeCommand = new ChangeStylesMacroCommand(d->documentUpdaterProxies, this);
+}
+
+void KoStyleManager::endEdit()
+{
+    Q_ASSERT (d->changeCommand);
+    if (d->undoStack) {
+        d->undoStack->push(d->changeCommand);
     }
-    d->updateQueue.clear();
-    d->updateTriggered = false;
-}
-
-void KoStyleManager::requestFireUpdate()
-{
-    if (d->updateTriggered)
-        return;
-    QTimer::singleShot(0, this, SLOT(updateAlteredStyles()));
-    d->updateTriggered = true;
+    d->changeCommand = 0;
 }
 
 void KoStyleManager::add(QTextDocument *document)
 {
+    if (!d->undoStack) {
+        d->undoStack = KoTextDocument(document).undoStack();
+    }
     foreach(ChangeFollower *cf, d->documentUpdaterProxies) {
         if (cf->document() == document) {
             return; // already present.
@@ -770,6 +874,27 @@ KoListStyle *KoStyleManager::defaultListStyle() const
     return d->defaultListStyle;
 }
 
+KoListStyle *KoStyleManager::defaultOutlineStyle() const
+{
+    if (!d->defaultOutlineStyle) {
+        d->defaultOutlineStyle = d->defaultListStyle->clone();
+
+        QList<int> levels = d->defaultOutlineStyle->listLevels();
+        foreach (int level, levels) {
+            KoListLevelProperties llp = d->defaultOutlineStyle->levelProperties(level);
+            llp.setOutlineList(true);
+            llp.setDisplayLevel(level);
+            llp.setTabStopPosition(0);
+            llp.setMargin(0);
+            llp.setTextIndent(0);
+            d->defaultOutlineStyle->setLevelProperties(llp);
+        }
+        d->defaultOutlineStyle->setStyleId(d->s_stylesNumber++);
+    }
+
+    return d->defaultOutlineStyle;
+}
+
 void KoStyleManager::setOutlineStyle(KoListStyle* listStyle)
 {
     if (d->outlineStyle && d->outlineStyle->parent() == this)
@@ -834,6 +959,21 @@ KoParagraphStyle *KoStyleManager::defaultTableOfcontentsTitleStyle()
     return defaultParagraphStyle();
 }
 
+KoParagraphStyle *KoStyleManager::defaultBibliographyEntryStyle(QString bibType)
+{
+    KoParagraphStyle *style = paragraphStyle(d->defaultBibEntriesStyleId
+                                             .at(KoOdfBibliographyConfiguration::bibTypes.indexOf(bibType)));
+    return style;
+}
+
+KoParagraphStyle *KoStyleManager::defaultBibliographyTitleStyle()
+{
+    KoParagraphStyle *style = new KoParagraphStyle();
+    style->setName("Bibliography Heading");
+    style->setFontPointSize(16);
+    return style;
+}
+
 void KoStyleManager::addUnusedStyle(KoParagraphStyle *style)
 {
     if (d->unusedParagraphStyles.key(style, -1) != -1)
