@@ -91,18 +91,11 @@ public:
      *        Usually passed by KPluginFactory::create.
      * @param parent may be another KoDocument, or anything else.
      *        Usually passed by KPluginFactory::create.
-     * @param singleViewMode determines whether the document may only have one view.
-     *        Usually passed by the derived factory, when KPluginFactory::create says the requested interface is not KoDocument.
-     *        In this case the @p parent must be a QWidget derived class.
-     *        KoDocument will then create a wrapper widget (KoViewWrapperWidget) which is a child of @p parentWidget.
-     *        This widget can be retrieved by calling widget().
      * @param undoStack accepts the stack for the document. You can create any type of stack if you need.
      *        The stack objects will become owned by the document. This is used by Krita's KisDoc2. The default value for this
      *        parameter is a usual Qt's stack.
      */
-    KoDocument(QWidget *parentWidget,
-               QObject *parent,
-               bool singleViewMode = false,
+    KoDocument(QObject *parent,
                KUndo2Stack *undoStack = new KUndo2Stack());
 
     /**
@@ -113,45 +106,6 @@ public:
      */
     virtual ~KoDocument();
 
-    /**
-     * Tells whether this document is in singleview mode. This mode can only be set
-     * in the constructor.
-     */
-    bool isSingleViewMode() const;
-
-    /**
-     * @return true if the document is embedded in another odf document
-     */
-    bool isEmbedded() const;
-
-    /**
-     * Returns the action described action object. In fact only the "name" attribute
-     * of @p element is of interest here. The method searches first in the
-     * KActionCollection of the first view and then in the KActionCollection of this
-     * document.
-     * This allows %Calligra applications to define actions in both the view and the document.
-     * They should only define view-actions (like zooming and stuff) in the view.
-     * Every action which changes the document should be defined in the document.
-     *
-     * Please notice that KoDocument indirectly inherits KXMLGUIClient.
-     *
-     * @see KXMLGUIClient
-     * @see KXMLGUIClient::actionCollection
-     * @see KoView::action
-     */
-    virtual QAction *action(const QDomElement &element) const;
-
-    /**
-     * Returns the DOM document which describes the GUI of the
-     * first view.
-     */
-    virtual QDomDocument domDocument() const;
-
-    /**
-     * @internal
-     */
-    virtual void setManager(KParts::PartManager *manager);
-
     /**
      * Reimplemented from KParts::ReadWritePart for internal reasons
      * (for the autosave functionality)
@@ -191,37 +145,6 @@ public:
      */
     virtual void setReadWrite(bool readwrite = true);
 
-    /**
-     * @brief Used by KoApplication, and by KoMainWindow, when no document exists yet.
-     *
-     * With the help of @p instance or KApplication::componentData() this
-     * method figures out which .desktop file matches this application. In this
-     * file it searches for the "X-KDE-NativeMimeType" entry and returns it.
-     *
-     * @see KService
-     * @see KDesktopFile
-     */
-    static QByteArray readNativeFormatMimeType(const KComponentData &instance = KComponentData());
-
-    /**
-     * Used by KoMainWindow, when no document exists yet.
-     *
-     * With the help of @p instance or KApplication::componentData() this
-     * method figures out which .desktop file matches this application. In this
-     * file it searches for the "X-KDE-ExtraNativeMimeTypes" entry and returns it.
-     *
-     * @see KService
-     * @see KDesktopFile
-     */
-    static QStringList readExtraNativeMimeTypes(const KComponentData &instance = KComponentData());
-
-    /**
-     * With the help of @p instance or KApplication::componentData() this
-     * method figures out which .desktop file matches this application,
-     * and returns the KService instance for it.
-     */
-    static KService::Ptr readNativeService(const KComponentData &instance = KComponentData());
-
     /**
      * To be preferred when a document exists. It is fast when calling
      * it multiple times since it caches the result that readNativeFormatMimeType()
@@ -319,8 +242,6 @@ public:
      */
     void setSaveInBatchMode(const bool batchMode);
 
-    virtual bool wantExportConfirmation() const;
-
     /**
      * Sets the error message to be shown to the user (use i18n()!)
      * when loading or saving fails.
@@ -392,15 +313,6 @@ public:
      */
     virtual KParts::Part *hitTest(QWidget *widget, const QPoint &globalPos);
 
-    /**
-     *  Paints the whole document into the given painter object.
-     *
-     *  @param painter     The painter object onto which will be drawn.
-     *  @param rect        The rect that should be used in the painter object.
-     *  @param view        The KoView is needed to fiddle about with the active widget, when painting children.
-     */
-    virtual void paintEverything(QPainter &painter, const QRect &rect, KoView *view = 0);
-
     /**
      * @brief Generates a preview picture of the document
      * @note The preview is used in the File Dialog and also to create the Thumbnail
@@ -408,22 +320,14 @@ public:
     virtual QPixmap generatePreview(const QSize& size);
 
     /**
-     *  Paints the data itself. Normally called by paintEverything(). It does not
-     *  paint the children.
+     *  Paints the data itself.
      *  It's this method that %Calligra Parts have to implement.
      *
      *  @param painter     The painter object onto which will be drawn.
      *  @param rect        The rect that should be used in the painter object.
-     *
-     *  @see #paintEverything
      */
     virtual void paintContent(QPainter &painter, const QRect &rect) = 0;
 
-    /**
-     * Called by koApplication to check for an autosave file in $HOME
-     */
-    bool checkAutoSaveFile();
-
     /**
      * Creates and shows the start up widget.
      * @param parent the KoMainWindow used as parent for the widget.
@@ -477,7 +381,7 @@ public:
     /**
      *  @brief Saves a sub-document to a store.
      *
-     *  You should not have to reimplement this - but call it in saveChildren().
+     *  You should not have to reimplement this.
      */
     virtual bool saveToStore(KoStore *store, const QString& path);
 
@@ -561,7 +465,8 @@ public:
     /**
      * Set whether the next openUrl call should check for an auto-saved file
      * and offer to open it. This is usually true, but can be turned off
-     * (e.g. for the preview module).
+     * (e.g. for the preview module). This only checks for names auto-saved
+     * files, unnamed auto-saved files are only checked on KoApplication startup.
      */
     void setCheckAutoSaveFile(bool b);
 
@@ -595,7 +500,7 @@ public:
      * the RDF system and needs full access to the KoDocumentRdf object.
      * @see KoDocumentRdf
      */
-    KoDocumentRdf *documentRdf() const;
+    KoDocumentRdfBase *documentRdf() const;
 
     /**
      * Replace the current rdf document with the given rdf document. The existing RDF document
@@ -734,7 +639,8 @@ public:
      * to set the url to KUrl()
      */
     void resetURL() {
-        setUrl(KUrl()); setLocalFilePath(QString());
+        setUrl(KUrl());
+        setLocalFilePath(QString());
     }
 
     /**
@@ -778,13 +684,6 @@ public:
      */
     void saveUnitOdf(KoXmlWriter *settingsWriter) const;
 
-    /**
-     * Returns the name of the unit used to display all measures/distances.
-     * Use this method for displaying it in the user interface, but use
-     * unit() for everything else (conversions etc.)
-     */
-    QString unitName() const;
-
     /**
      * Set the template type used. This is used by the start up widget to show
      * the correct templates.
@@ -874,6 +773,7 @@ public slots:
      * Set the output stream to report profile information to.
      */
     void setProfileReferenceTime(const QTime& referenceTime);
+
 signals:
 
     /**
@@ -941,6 +841,8 @@ protected:
 
     QString autoSaveFile(const QString & path) const;
 
+
+
     virtual KoView *createViewInstance(QWidget *parent) = 0;
 
     /**
@@ -1060,6 +962,7 @@ private:
 
     bool saveToStream(QIODevice *dev);
 
+    QString checkImageMimeTypes(const QString &mimeType, const KUrl& url) const;
 
     /// @return the current KoMainWindow shell
     KoMainWindow *currentShell();
