@@ -59,7 +59,7 @@ KoPageLayoutWidget::KoPageLayoutWidget(QWidget *parent, const KoPageLayout &layo
     width = qMax(width, qMax(d->widget.leftLabel->width(), d->widget.rightLabel->width()));
     d->widget.leftLabel->setMinimumSize(QSize(width, 5));
 
-    d->widget.units->addItems(KoUnit::listOfUnitName());
+    d->widget.units->addItems(KoUnit::listOfUnitNameForUi(KoUnit::HidePixel));
     d->widget.sizes->addItems(KoPageFormat::allFormats());
     setPageSpread(false);
 
@@ -126,7 +126,7 @@ void KoPageLayoutWidget::sizeChanged(int row)
 
 void KoPageLayoutWidget::unitChanged(int row)
 {
-    setUnit(KoUnit(static_cast<KoUnit::Unit> (row)));
+    setUnit(KoUnit::fromListForUi(row, KoUnit::HidePixel));
 }
 
 void KoPageLayoutWidget::setUnit(const KoUnit &unit)
@@ -141,7 +141,7 @@ void KoPageLayoutWidget::setUnit(const KoUnit &unit)
     d->widget.bottomMargin->setUnit(unit);
     d->widget.bindingEdgeMargin->setUnit(unit);
     d->widget.pageEdgeMargin->setUnit(unit);
-    d->widget.units->setCurrentIndex(unit.indexInList());
+    d->widget.units->setCurrentIndex(unit.indexInListForUi(KoUnit::HidePixel));
 
     emit unitChanged(d->unit);
 }
