@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-  Copyright (C) 2009 Dag Andersen danders@get2net>
+  Copyright (C) 2009, 2012 Dag Andersen danders@get2net>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -29,6 +29,7 @@
 #include "kpttask.h"
 #include "kptresource.h"
 #include "kptdatetime.h"
+#include "kptdebug.h"
 
 #include <QMimeData>
 #include <QObject>
@@ -40,10 +41,7 @@
 #include <klocale.h>
 #include <kactioncollection.h>
 #include <kxmlguifactory.h>
-#include <kabc/addressee.h>
-#include <kabc/vcardconverter.h>
 
-#include <kdebug.h>
 
 namespace KPlato
 {
@@ -83,7 +81,7 @@ int ResourceAllocationModel::propertyCount() const
 
 QVariant ResourceAllocationModel::name( const Resource *res, int role ) const
 {
-    //kDebug()<<res->name()<<","<<role;
+    //kDebug(planDbg())<<res->name()<<","<<role;
     switch ( role ) {
         case Qt::DisplayRole:
         case Qt::EditRole:
@@ -98,7 +96,7 @@ QVariant ResourceAllocationModel::name( const Resource *res, int role ) const
 
 QVariant ResourceAllocationModel::name( const  ResourceGroup *res, int role ) const
 {
-    //kDebug()<<res->name()<<","<<role;
+    //kDebug(planDbg())<<res->name()<<","<<role;
     switch ( role ) {
         case Qt::DisplayRole:
         case Qt::EditRole:
@@ -257,8 +255,14 @@ QVariant ResourceAllocationModel::required( const Resource *res, int role ) cons
         case Qt::TextAlignmentRole:
             return Qt::AlignCenter;
         case Qt::StatusTipRole:
-        case Qt::WhatsThisRole:
             return QVariant();
+        case Qt::WhatsThisRole:
+            return i18nc( "@info:whatsthis", "<title>Required Resources</title>"
+            "<para>A working resource can be assigned to one or more required resources."
+            " A required resource is a material resource that the working resource depends on"
+            " in order to do the work.</para>"
+            "<para>To be able to use a material resource as a required resource, the material resource"
+            " must be part of a group of type <emphasis>Material</emphasis>.</para>" );
     }
     return QVariant();
 }
@@ -293,7 +297,7 @@ QVariant ResourceAllocationModel::data( const ResourceGroup *group, const Resour
         case RequestMaximum: result = maximum( resource, role ); break;
         case RequestRequired: result = required( resource, role ); break;
         default:
-            kDebug()<<"data: invalid display value: property="<<property;
+            kDebug(planDbg())<<"data: invalid display value: property="<<property;
             break;
     }
     return result;
@@ -315,7 +319,7 @@ QVariant ResourceAllocationModel::data( const ResourceGroup *group, int property
                 if ( property < propertyCount() ) {
                     result = "";
                 } else {
-                    kDebug()<<"data: invalid display value column"<<property;;
+                    kDebug(planDbg())<<"data: invalid display value column"<<property;;
                     return QVariant();
                 }
             }
@@ -347,13 +351,23 @@ QVariant ResourceAllocationModel::headerData( int section, int role )
             case RequestType: return ToolTip::resourceType();
             case RequestAllocation: return i18n( "Resource allocation" );
             case RequestMaximum: return i18nc( "@info:tootip", "Available resources or resource units" );
-            case RequestRequired: return i18nc( "@info:tootip", "Required Resources" );
+            case RequestRequired: return i18nc( "@info:tootip", "Required material resources" );
+            default: return QVariant();
+        }
+    } else if ( role == Qt::WhatsThisRole ) {
+        switch ( section ) {
+            case RequestRequired:
+                return i18nc( "@info:whatsthis", "<title>Required Resources</title>"
+                "<para>A working resource can be assigned to one or more required resources."
+                " A required resource is a material resource that the working resource depends on"
+                " in order to do the work.</para>"
+                "<para>To be able to use a material resource as a required resource, the material resource"
+                " must be part of a group of type Material.</para>" );
             default: return QVariant();
         }
     }
     return QVariant();
 }
-
 //--------------------------------------
 
 ResourceAllocationItemModel::ResourceAllocationItemModel( QObject *parent )
@@ -367,52 +381,52 @@ ResourceAllocationItemModel::~ResourceAllocationItemModel()
 
 void ResourceAllocationItemModel::slotResourceToBeInserted( const ResourceGroup *group, int row )
 {
-    //kDebug()<<group->name()<<","<<row;
+    //kDebug(planDbg())<<group->name()<<","<<row;
     beginInsertRows( index( group ), row, row );
 }
 
 void ResourceAllocationItemModel::slotResourceInserted( const Resource */*resource */)
 {
-    //kDebug()<<resource->name();
+    //kDebug(planDbg())<<resource->name();
     endInsertRows();
     emit layoutChanged(); //HACK to make the right view react! Bug in qt?
 }
 
 void ResourceAllocationItemModel::slotResourceToBeRemoved( const Resource *resource )
 {
-    //kDebug()<<resource->name();
+    //kDebug(planDbg())<<resource->name();
     int row = index( resource ).row();
     beginRemoveRows( index( resource->parentGroup() ), row, row );
 }
 
 void ResourceAllocationItemModel::slotResourceRemoved( const Resource */*resource */)
 {
-    //kDebug()<<resource->name();
+    //kDebug(planDbg())<<resource->name();
     endRemoveRows();
 }
 
 void ResourceAllocationItemModel::slotResourceGroupToBeInserted( const ResourceGroup */*group*/, int row )
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     beginInsertRows( QModelIndex(), row, row );
 }
 
 void ResourceAllocationItemModel::slotResourceGroupInserted( const ResourceGroup */*group */)
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     endInsertRows();
 }
 
 void ResourceAllocationItemModel::slotResourceGroupToBeRemoved( const ResourceGroup *group )
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     int row = index( group ).row();
     beginRemoveRows( QModelIndex(), row, row );
 }
 
 void ResourceAllocationItemModel::slotResourceGroupRemoved( const ResourceGroup */*group */)
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     endRemoveRows();
 }
 
@@ -509,15 +523,32 @@ void ResourceAllocationItemModel::filldata( Task *task )
     }
 }
 
+bool ResourceAllocationItemModel::hasMaterialResources() const
+{
+    if ( ! m_project ) {
+        return false;
+    }
+    foreach ( const ResourceGroup *g, m_project->resourceGroups() ) {
+        if ( g->type() == ResourceGroup::Type_Material ) {
+            foreach ( const Resource *r, g->resources() ) {
+                if ( r->type() == Resource::Type_Material ) {
+                    return true;
+                }
+            }
+        }
+    }
+    return false;
+}
+
 Qt::ItemFlags ResourceAllocationItemModel::flags( const QModelIndex &index ) const
 {
     Qt::ItemFlags flags = ItemModelBase::flags( index );
     if ( !m_readWrite ) {
-        //kDebug()<<"read only"<<flags;
+        //kDebug(planDbg())<<"read only"<<flags;
         return flags &= ~Qt::ItemIsEditable;
     }
     if ( !index.isValid() ) {
-        //kDebug()<<"invalid"<<flags;
+        //kDebug(planDbg())<<"invalid"<<flags;
         return flags;
     }
     switch ( index.column() ) {
@@ -526,11 +557,13 @@ Qt::ItemFlags ResourceAllocationItemModel::flags( const QModelIndex &index ) con
             break;
         case ResourceAllocationModel::RequestRequired: {
             Resource *r = resource( index );
-            if ( m_resourceCache.contains( r ) && m_resourceCache[ r ]->units() > 0 ) {
-                flags |= ( Qt::ItemIsEditable | Qt::ItemIsUserCheckable );
-            }
             if ( r && r->type() != Resource::Type_Work ) {
                 flags &= ~( Qt::ItemIsEditable | Qt::ItemIsUserCheckable );
+            } else if ( m_resourceCache.contains( r ) && m_resourceCache[ r ]->units() > 0 ) {
+                flags |= ( Qt::ItemIsEditable | Qt::ItemIsUserCheckable );
+                if ( ! hasMaterialResources() ) {
+                    flags &= ~Qt::ItemIsEnabled;
+                }
             }
             break;
         }
@@ -547,7 +580,7 @@ QModelIndex ResourceAllocationItemModel::parent( const QModelIndex &index ) cons
     if ( !index.isValid() || m_project == 0 ) {
         return QModelIndex();
     }
-    //kDebug()<<index.internalPointer()<<":"<<index.row()<<","<<index.column();
+    //kDebug(planDbg())<<index.internalPointer()<<":"<<index.row()<<","<<index.column();
 
     Resource *r = qobject_cast<Resource*>( object( index ) );
     if ( r && r->parentGroup() ) {
@@ -665,6 +698,17 @@ QVariant ResourceAllocationItemModel::allocation( const ResourceGroup *group, co
     return QVariant();
 }
 
+int ResourceAllocationItemModel::requestedResources( const ResourceGroup *res ) const
+{
+    int c = 0;
+    foreach ( const Resource *r, res->resources() ) {
+        if ( m_resourceCache.contains( r ) &&  m_resourceCache[ r ]->units() > 0 ) {
+            ++c;
+        }
+    }
+    return c;
+}
+
 QVariant ResourceAllocationItemModel::allocation( const ResourceGroup *res, int role ) const
 {
     if ( m_model.task() == 0 ) {
@@ -675,13 +719,36 @@ QVariant ResourceAllocationItemModel::allocation( const ResourceGroup *res, int
     }
     switch ( role ) {
         case Qt::DisplayRole:
+            return QString(" %1 (%2)" )
+                        .arg( qMax( m_groupCache[ res ]->units(), allocation( res, Role::Minimum ).toInt() ) )
+                        .arg(requestedResources( res ) );
         case Qt::EditRole:
             return qMax( m_groupCache[ res ]->units(), allocation( res, Role::Minimum ).toInt() );
-        case Qt::ToolTipRole:
-            return i18np( "%1 resource allocated", "%1 resources allocated", allocation( res, Qt::DisplayRole ).toInt() );
+        case Qt::ToolTipRole: {
+            QString s1 = i18ncp( "@info:tooltip",
+                                 "%1 resource requested for dynamic allocation",
+                                 "%1 resources requested for dynamic allocation",
+                                 allocation( res, Qt::EditRole ).toInt() );
+            QString s2 = i18ncp( "@info:tooltip",
+                                 "%1 resource allocated",
+                                 "%1 resources allocated",
+                                 requestedResources( res ) );
+
+            return i18nc( "@info:tooltip", "%1<nl/>%2", s1, s2 );
+        }
+        case Qt::WhatsThisRole: {
+            return i18nc( "@info:whatsthis",
+                          "<title>Group allocations</title>"
+                          "<para>You can allocate a number of resources from a group and let"
+                          " the scheduler select from the available resources at the time of scheduling.</para>"
+                          " These dynamically allocated resources will be in addition to any resource you have allocated specifically." );
+        }
         case Role::Minimum: {
             return 0;
         }
+        case Role::Maximum: {
+            return res->numResources() - requestedResources( res );
+        }
         default:
             return m_model.allocation( res, role );
     }
@@ -693,18 +760,30 @@ bool ResourceAllocationItemModel::setAllocation( Resource *res, const QVariant &
     switch ( role ) {
         case Qt::EditRole: {
             m_resourceCache[ res ]->setUnits( value.toInt() );
+            QModelIndex idx = index( res->parentGroup() );
+            emit dataChanged( index( idx.row(), 0, QModelIndex() ), index( idx.row(), columnCount() - 1, QModelIndex() ) );
             return true;
         }
-        case Qt::CheckStateRole:
+        case Qt::CheckStateRole: {
             if ( ! m_resourceCache.contains( res ) ) {
                 m_resourceCache[ res ] = new ResourceRequest( res, 0 );
             }
             if ( m_resourceCache[ res ]->units() == 0 ) {
                 m_resourceCache[ res ]->setUnits( 100 );
+                ResourceGroup *g = res->parentGroup();
+                if ( m_groupCache.contains( g ) ) {
+                    ResourceGroupRequest *gr = m_groupCache[ g ];
+                    if ( gr->units() + requestedResources( g ) > g->numResources() ) {
+                        gr->setUnits( gr->units() - 1 );
+                    }
+                }
             } else {
                 m_resourceCache[ res ]->setUnits( 0 );
             }
+            QModelIndex idx = index( res->parentGroup() );
+            emit dataChanged( index( idx.row(), 0, QModelIndex() ), index( idx.row(), columnCount() - 1, QModelIndex() ) );
             return true;
+        }
     }
     return false;
 }
@@ -717,11 +796,30 @@ bool ResourceAllocationItemModel::setAllocation( ResourceGroup *res, const QVari
                 m_groupCache[ res ] = new ResourceGroupRequest( res, 0 );
             }
             m_groupCache[ res ]->setUnits( value.toInt() );
+            emit dataChanged( index( res ), index( res ) );
             return true;
     }
     return false;
 }
 
+QVariant ResourceAllocationItemModel::maximum( const ResourceGroup *res, int role ) const
+{
+    switch ( role ) {
+        case Qt::DisplayRole: {
+            int c = res->numResources() - requestedResources( res );
+            if ( m_groupCache.contains( res ) ) {
+                c -= m_groupCache[ res ]->units();
+            }
+            return i18nc( "1: free resources, 2: number of resources", "%1 of %2", c, res->numResources() );
+        }
+        case Qt::ToolTipRole:
+            return i18ncp( "@info:tooltip", "There is %1 resource available in this group", "There are %1 resources available in this group", res->numResources() );
+        default:
+            return m_model.maximum( res, role );
+    }
+    return QVariant();
+}
+
 QVariant ResourceAllocationItemModel::required( const QModelIndex &idx, int role ) const
 {
     if ( m_model.task() == 0 ) {
@@ -748,6 +846,9 @@ QVariant ResourceAllocationItemModel::required( const QModelIndex &idx, int role
         case Qt::ToolTipRole: 
             switch ( res->type() ) {
                 case Resource::Type_Work: {
+                    if ( ! hasMaterialResources() ) {
+                        return i18nc( "@info:tooltip", "No material resources available" );
+                    }
                     QStringList lst;
                     if ( m_requiredChecked[ res ] ) {
                         foreach ( const Resource *r, required( idx ) ) {
@@ -768,7 +869,7 @@ QVariant ResourceAllocationItemModel::required( const QModelIndex &idx, int role
             }
             break;
         default:
-            break;
+            return m_model.required( res, role );
     }
     return QVariant();
 }
@@ -830,10 +931,17 @@ QVariant ResourceAllocationItemModel::data( const QModelIndex &index, int role )
     } else {
         ResourceGroup *g = qobject_cast<ResourceGroup*>( obj );
         if ( g ) {
-            if ( index.column() == ResourceAllocationModel::RequestAllocation ) {
-                return allocation( g, role );
+            switch ( index.column() ) {
+                case ResourceAllocationModel::RequestAllocation:
+                    result = allocation( g, role );
+                    break;
+                case ResourceAllocationModel::RequestMaximum:
+                    result = maximum( g, role );
+                    break;
+                default:
+                    result = m_model.data( g, index.column(), role );
+                    break;
             }
-            result = m_model.data( g, index.column(), role );
         }
     }
     if ( role == Qt::DisplayRole && ! result.isValid() ) {
@@ -900,10 +1008,7 @@ QVariant ResourceAllocationItemModel::headerData( int section, Qt::Orientation o
             return Qt::AlignCenter;
         }
     }
-    if ( role == Qt::ToolTipRole ) {
-        return m_model.headerData( section, role );
-    }
-    return ItemModelBase::headerData(section, orientation, role);
+    return m_model.headerData( section, role );
 }
 
 QAbstractItemDelegate *ResourceAllocationItemModel::createDelegate( int col, QWidget *parent ) const
