@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 - 2010 Dag Andersen <danders@get2net.dk>
+  Copyright (C) 2007 - 2010, 2012 Dag Andersen <danders@get2net.dk>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -26,6 +26,7 @@
 #include "kptproject.h"
 #include "kptschedule.h"
 #include "kpteffortcostmap.h"
+#include "kptdebug.h"
 
 #include <KoDocument.h>
 
@@ -71,6 +72,7 @@
 #include "KDChartBackgroundAttributes"
 #include "KDChartGridAttributes"
 
+
 using namespace KDChart;
 
 namespace KPlato
@@ -213,7 +215,7 @@ TaskStatusView::TaskStatusView( KoDocument *part, QWidget *parent )
     : ViewBase( part, parent ),
     m_id( -1 )
 {
-    kDebug()<<"-------------------- creating TaskStatusView -------------------";
+    kDebug(planDbg())<<"-------------------- creating TaskStatusView -------------------";
     QVBoxLayout * l = new QVBoxLayout( this );
     l->setMargin( 0 );
     m_view = new TaskStatusTreeView( this );
@@ -234,7 +236,7 @@ void TaskStatusView::updateReadWrite( bool rw )
 
 void TaskStatusView::setScheduleManager( ScheduleManager *sm )
 {
-    //kDebug();
+    //kDebug(planDbg());
     static_cast<TaskStatusItemModel*>( m_view->model() )->setScheduleManager( sm );
 }
 
@@ -256,14 +258,14 @@ void TaskStatusView::draw( Project &project )
 
 void TaskStatusView::setGuiActive( bool activate )
 {
-    kDebug()<<activate;
+    kDebug(planDbg())<<activate;
 //    updateActionsEnabled( true );
     ViewBase::setGuiActive( activate );
 }
 
 void TaskStatusView::slotContextMenuRequested( const QModelIndex &index, const QPoint& pos )
 {
-    kDebug()<<index<<pos;
+    kDebug(planDbg())<<index<<pos;
     if ( ! index.isValid() ) {
         slotHeaderContextMenuRequested( pos );
         return;
@@ -278,7 +280,7 @@ void TaskStatusView::slotContextMenuRequested( const QModelIndex &index, const Q
 
 void TaskStatusView::slotContextMenuRequested( Node *node, const QPoint& pos )
 {
-    kDebug()<<node->name()<<" :"<<pos;
+    kDebug(planDbg())<<node->name()<<" :"<<pos;
     QString name;
     switch ( node->type() ) {
         case Node::Type_Task:
@@ -293,7 +295,7 @@ void TaskStatusView::slotContextMenuRequested( Node *node, const QPoint& pos )
         default:
             break;
     }
-    kDebug()<<name;
+    kDebug(planDbg())<<name;
     if ( name.isEmpty() ) {
         slotHeaderContextMenuRequested( pos );
         return;
@@ -312,7 +314,7 @@ void TaskStatusView::setupGui()
 
 void TaskStatusView::slotSplitView()
 {
-    kDebug();
+    kDebug(planDbg());
     m_view->setViewSplitMode( ! m_view->isViewSplit() );
     emit optionsModified();
 }
@@ -324,7 +326,7 @@ void TaskStatusView::slotRefreshView()
 
 void TaskStatusView::slotOptions()
 {
-    kDebug();
+    kDebug(planDbg());
     TaskStatusViewSettingsDialog *dlg = new TaskStatusViewSettingsDialog( m_view, this );
     connect(dlg, SIGNAL(finished(int)), SLOT(slotOptionsFinished(int)));
     dlg->show();
@@ -334,7 +336,8 @@ void TaskStatusView::slotOptions()
 
 bool TaskStatusView::loadContext( const KoXmlElement &context )
 {
-    kDebug();
+    kDebug(planDbg());
+    ViewBase::loadContext( context );
     m_view->setPeriod( context.attribute( "period", QString("%1").arg( m_view->defaultPeriod() ) ).toInt() );
 
     m_view->setPeriodType( context.attribute( "periodtype", QString("%1").arg( m_view->defaultPeriodType() ) ).toInt() );
@@ -345,6 +348,7 @@ bool TaskStatusView::loadContext( const KoXmlElement &context )
 
 void TaskStatusView::saveContext( QDomElement &context ) const
 {
+    ViewBase::saveContext( context );
     context.setAttribute( "period", m_view->period() );
     context.setAttribute( "periodtype", m_view->periodType() );
     context.setAttribute( "weekday", m_view->weekday() );
@@ -426,7 +430,7 @@ ProjectStatusView::ProjectStatusView( KoDocument *part, QWidget *parent )
     : ViewBase( part, parent ),
     m_project( 0 )
 {
-    kDebug()<<"-------------------- creating ProjectStatusView -------------------";
+    kDebug(planDbg())<<"-------------------- creating ProjectStatusView -------------------";
     QVBoxLayout * l = new QVBoxLayout( this );
     l->setMargin( 0 );
     m_view = new PerformanceStatusBase( this );
@@ -441,7 +445,7 @@ ProjectStatusView::ProjectStatusView( KoDocument *part, QWidget *parent )
 
 void ProjectStatusView::setScheduleManager( ScheduleManager *sm )
 {
-    //kDebug();
+    //kDebug(planDbg());
     m_view->setScheduleManager( sm );
     m_view->model()->clearNodes();
     if ( m_project ) {
@@ -458,7 +462,7 @@ void ProjectStatusView::setProject( Project *project )
 
 void ProjectStatusView::setGuiActive( bool activate )
 {
-    kDebug()<<activate;
+    kDebug(planDbg())<<activate;
 //    updateActionsEnabled( true );
     ViewBase::setGuiActive( activate );
 }
@@ -480,12 +484,14 @@ void ProjectStatusView::slotOptions()
 
 bool ProjectStatusView::loadContext( const KoXmlElement &context )
 {
-    kDebug();
+    kDebug(planDbg());
+    ViewBase::loadContext( context );
     return m_view->loadContext( context );
 }
 
 void ProjectStatusView::saveContext( QDomElement &context ) const
 {
+    ViewBase::saveContext( context );
     m_view->saveContext( context );
 }
 
@@ -517,7 +523,7 @@ QList<QWidget*> PerformanceStatusPrintingDialog::createOptionWidgets() const
 
 void PerformanceStatusPrintingDialog::printPage( int page, QPainter &painter )
 {
-    //kDebug()<<page<<printer().pageRect()<<printer().paperRect()<<printer().margins()<<printer().fullPage();
+    //kDebug(planDbg())<<page<<printer().pageRect()<<printer().paperRect()<<printer().margins()<<printer().fullPage();
     painter.save();
     QRect rect = printer().pageRect();
     rect.moveTo( 0, 0 ); // the printer already has margins set
@@ -536,7 +542,7 @@ void PerformanceStatusPrintingDialog::printPage( int page, QPainter &painter )
     if ( rect.height() > rect.width() && r > 0.0 ) {
         rect.setHeight( rect.width() / r );
     }
-    kDebug()<<s<<rect;
+    kDebug(planDbg())<<s<<rect;
     m_chart->ui_chart->paint( &painter, rect );
     painter.restore();
 }
@@ -567,7 +573,7 @@ PerformanceStatusBase::PerformanceStatusBase( QWidget *parent )
             QTableWidgetItem *itm = ui_performancetable->item( r, c );
             Q_ASSERT( itm );
             itm->setFlags( Qt::ItemIsEnabled );
-            kDebug()<<itm<<itm->flags();
+            kDebug(planDbg())<<itm<<itm->flags();
         }
     }
 
@@ -731,7 +737,7 @@ void PerformanceStatusBase::setupChart()
     } else /*if ( m_chartinfo.showLineChart )*/ {
         setupChart( m_linechart );
     }
-    kDebug()<<"Planes:"<<ui_chart->coordinatePlanes();
+    kDebug(planDbg())<<"Planes:"<<ui_chart->coordinatePlanes();
     foreach ( AbstractCoordinatePlane *pl, ui_chart->coordinatePlanes() ) {
         CartesianCoordinatePlane *p = dynamic_cast<CartesianCoordinatePlane*>( pl );
         if ( p == 0 ) continue;
@@ -779,7 +785,7 @@ void PerformanceStatusBase::setupChart( ChartContents &cc )
     int effort_start_column = 3; // proxy column number
 
     const PerformanceChartInfo &info = m_chartinfo;
-    kDebug()<<"cost="<<info.showCost<<"effort="<<info.showEffort;
+    kDebug(planDbg())<<"cost="<<info.showCost<<"effort="<<info.showEffort;
     static_cast<AbstractCartesianDiagram*>( cc.effortplane->diagram() )->takeAxis( cc.dateaxis );
     static_cast<AbstractCartesianDiagram*>( cc.costplane->diagram() )->takeAxis( cc.dateaxis );
     cc.costplane->setReferenceCoordinatePlane( 0 );
@@ -840,32 +846,32 @@ void PerformanceStatusBase::setupChart( ChartContents &cc )
         cc.costproxy.setZeroColumns( czc );
         cc.costproxy.setRejectColumns( crc );
     }
-#if 1
-    kDebug()<<"Effort:"<<info.showEffort;
+#if 0
+    kDebug(planDbg())<<"Effort:"<<info.showEffort;
     if ( info.showEffort && cc.effortproxy.rowCount() > 0 ) {
-        kDebug()<<"Effort:"<<info.showEffort<<"columns ="<<cc.effortproxy.columnCount()
+        kDebug(planDbg())<<"Effort:"<<info.showEffort<<"columns ="<<cc.effortproxy.columnCount()
             <<"reject="<<cc.effortproxy.rejectColumns()
             <<"zero="<<cc.effortproxy.zeroColumns();
         int row = cc.effortproxy.rowCount()-1;
         for ( int i = 0; i < cc.effortproxy.columnCount(); ++i ) {
-            kDebug()<<"data ("<<row<<","<<i<<":"<<cc.effortproxy.index(row,i).data().toString()<<(cc.effortplane->diagram()->isHidden(i)?"hide":"show");;
+            kDebug(planDbg())<<"data ("<<row<<","<<i<<":"<<cc.effortproxy.index(row,i).data().toString()<<(cc.effortplane->diagram()->isHidden(i)?"hide":"show");;
         }
     }
-    kDebug()<<"Cost:"<<info.showCost;
+    kDebug(planDbg())<<"Cost:"<<info.showCost;
     if ( info.showCost && cc.costproxy.rowCount() > 0 ) {
-        kDebug()<<"Cost:"<<info.showCost<<"columns ="<<cc.costproxy.columnCount()
+        kDebug(planDbg())<<"Cost:"<<info.showCost<<"columns ="<<cc.costproxy.columnCount()
             <<"reject="<<cc.costproxy.rejectColumns()
             <<"zero="<<cc.costproxy.zeroColumns();
         int row = cc.costproxy.rowCount()-1;
         for ( int i = 0; i < cc.costproxy.columnCount(); ++i ) {
-            kDebug()<<"data ("<<row<<","<<i<<":"<<cc.costproxy.index(row,i).data().toString()<<(cc.costplane->diagram()->isHidden(i)?"hide":"show");;
+            kDebug(planDbg())<<"data ("<<row<<","<<i<<":"<<cc.costproxy.index(row,i).data().toString()<<(cc.costplane->diagram()->isHidden(i)?"hide":"show");;
         }
     }
 
     foreach( AbstractCoordinatePlane *p, ui_chart->coordinatePlanes() ) {
-        kDebug()<<p<<"refrences:"<<p->referenceCoordinatePlane();
+        kDebug(planDbg())<<p<<"refrences:"<<p->referenceCoordinatePlane();
         foreach ( AbstractDiagram *d, p->diagrams() ) {
-            qDebug()<<p<<"diagram:"<<d;
+            kDebug(planDbg())<<p<<"diagram:"<<d;
         }
     }
 #endif
@@ -873,20 +879,20 @@ void PerformanceStatusBase::setupChart( ChartContents &cc )
 
 void PerformanceStatusBase::contextMenuEvent( QContextMenuEvent *event )
 {
-    kDebug()<<event->globalPos();
+    kDebug(planDbg())<<event->globalPos();
     emit customContextMenuRequested( event->globalPos() );
 }
 
 void PerformanceStatusBase::slotUpdate()
 {
-    //kDebug();
+    //kDebug(planDbg());
     drawValues();
     refreshChart();
 }
 
 void PerformanceStatusBase::setScheduleManager( ScheduleManager *sm )
 {
-    //kDebug();
+    //kDebug(planDbg());
     m_manager = sm;
     m_chartmodel.setScheduleManager( sm );
 }
@@ -907,7 +913,7 @@ void PerformanceStatusBase::setProject( Project *project )
 
 void PerformanceStatusBase::slotLocaleChanged()
 {
-    kDebug();
+    kDebug(planDbg());
     KLocale *locale = m_project ? m_project->locale() : KGlobal::locale();
     if ( locale ) {
         m_linechart.costaxis->setTitleText( i18nc( "Chart axis title 1=currency symbol", "Cost (%1)", m_project->locale()->currencySymbol() ) );
@@ -979,7 +985,7 @@ void PerformanceStatusBase::drawValues()
 
 bool PerformanceStatusBase::loadContext( const KoXmlElement &context )
 {
-    kDebug();
+    kDebug(planDbg());
     m_chartinfo.showBarChart = context.attribute( "show-bar-chart", "0" ).toInt();
     m_chartinfo.showLineChart = context.attribute( "show-line-chart", "1" ).toInt();
 
@@ -992,8 +998,8 @@ bool PerformanceStatusBase::loadContext( const KoXmlElement &context )
     m_chartinfo.showBCWSEffort = context.attribute( "show-bcws-effort", "1" ).toInt();
     m_chartinfo.showBCWPEffort = context.attribute( "show-bcwp-effort", "1" ).toInt();
     m_chartinfo.showACWPEffort = context.attribute( "show-acwp-effort", "1" ).toInt();
-    kDebug()<<"Cost:"<<m_chartinfo.showCost<<"bcws="<<m_chartinfo.showBCWSCost<<"bcwp="<<m_chartinfo.showBCWPCost<<"acwp="<<m_chartinfo.showACWPCost;
-    kDebug()<<"Effort:"<<m_chartinfo.showCost<<"bcws="<<m_chartinfo.showBCWSCost<<"bcwp="<<m_chartinfo.showBCWPCost<<"acwp="<<m_chartinfo.showACWPCost;
+    kDebug(planDbg())<<"Cost:"<<m_chartinfo.showCost<<"bcws="<<m_chartinfo.showBCWSCost<<"bcwp="<<m_chartinfo.showBCWPCost<<"acwp="<<m_chartinfo.showACWPCost;
+    kDebug(planDbg())<<"Effort:"<<m_chartinfo.showCost<<"bcws="<<m_chartinfo.showBCWSCost<<"bcwp="<<m_chartinfo.showBCWPCost<<"acwp="<<m_chartinfo.showACWPCost;
     setupChart();
     return true;
 }
@@ -1041,7 +1047,7 @@ PerformanceStatusTreeView::PerformanceStatusTreeView( QWidget *parent )
 
 void PerformanceStatusTreeView::slotSelectionChanged( const QItemSelection&, const QItemSelection& )
 {
-    //kDebug();
+    //kDebug(planDbg());
     QList<Node*> nodes;
     foreach ( const QModelIndex &i, m_tree->selectionModel()->selectedIndexes() ) {
         Node *n = nodeModel()->node( i );
@@ -1076,7 +1082,7 @@ void PerformanceStatusTreeView::setProject( Project *project )
 
 bool PerformanceStatusTreeView::loadContext( const KoXmlElement &context )
 {
-    kDebug();
+    kDebug(planDbg());
 
     bool res = false;
     res = m_chart->loadContext( context.namedItem( "chart" ).toElement() );
@@ -1123,7 +1129,7 @@ void PerformanceStatusTreeView::resizeSplitters()
 PerformanceStatusView::PerformanceStatusView( KoDocument *part, QWidget *parent )
     : ViewBase( part, parent )
 {
-    kDebug()<<"-------------------- creating PerformanceStatusView -------------------";
+    kDebug(planDbg())<<"-------------------- creating PerformanceStatusView -------------------";
     QVBoxLayout * l = new QVBoxLayout( this );
     l->setMargin( 0 );
     m_view = new PerformanceStatusTreeView( this );
@@ -1139,7 +1145,7 @@ PerformanceStatusView::PerformanceStatusView( KoDocument *part, QWidget *parent
 
 void PerformanceStatusView::slotContextMenuRequested( const QModelIndex &index, const QPoint& pos )
 {
-    kDebug()<<index<<pos;
+    kDebug(planDbg())<<index<<pos;
     if ( ! index.isValid() ) {
         slotHeaderContextMenuRequested( pos );
         return;
@@ -1159,7 +1165,7 @@ Node *PerformanceStatusView::currentNode() const
 
 void PerformanceStatusView::slotContextMenuRequested( Node *node, const QPoint& pos )
 {
-    kDebug()<<node->name()<<" :"<<pos;
+    kDebug(planDbg())<<node->name()<<" :"<<pos;
     QString name;
     switch ( node->type() ) {
         case Node::Type_Task:
@@ -1174,7 +1180,7 @@ void PerformanceStatusView::slotContextMenuRequested( Node *node, const QPoint&
         default:
             break;
     }
-    //kDebug()<<name;
+    //kDebug(planDbg())<<name;
     if ( name.isEmpty() ) {
         slotHeaderContextMenuRequested( pos );
         return;
@@ -1185,7 +1191,7 @@ void PerformanceStatusView::slotContextMenuRequested( Node *node, const QPoint&
 
 void PerformanceStatusView::setScheduleManager( ScheduleManager *sm )
 {
-    //kDebug();
+    //kDebug(planDbg());
     m_view->setScheduleManager( sm );
 }
 
@@ -1196,7 +1202,7 @@ void PerformanceStatusView::setProject( Project *project )
 
 void PerformanceStatusView::setGuiActive( bool activate )
 {
-    kDebug()<<activate;
+    kDebug(planDbg())<<activate;
 //    updateActionsEnabled( true );
     ViewBase::setGuiActive( activate );
 }
@@ -1209,7 +1215,7 @@ void PerformanceStatusView::setupGui()
 
 void PerformanceStatusView::slotOptions()
 {
-    kDebug();
+    kDebug(planDbg());
     PerformanceStatusViewSettingsDialog *dlg = new PerformanceStatusViewSettingsDialog( m_view, this );
     connect(dlg, SIGNAL(finished(int)), SLOT(slotOptionsFinished(int)));
     dlg->show();
@@ -1219,12 +1225,14 @@ void PerformanceStatusView::slotOptions()
 
 bool PerformanceStatusView::loadContext( const KoXmlElement &context )
 {
-    kDebug();
+    kDebug(planDbg());
+    ViewBase::loadContext( context );
     return m_view->loadContext( context );
 }
 
 void PerformanceStatusView::saveContext( QDomElement &context ) const
 {
+    ViewBase::saveContext( context );
     m_view->saveContext( context );
 }
 
