@@ -30,7 +30,8 @@ VectorToolFactory::VectorToolFactory()
     : KoToolFactoryBase("VectorToolFactoryId")
 {
     setToolTip( i18n( "EMF/WMF Vector Shape tool" ) );
-    setIcon( "vectorshape" );
+    // FIXME: x-shape-vectorimage
+    setIcon("application-x-wmf");
     setToolType( dynamicToolType() );
     setPriority( 1 );
     setActivationShapeId( VectorShape_SHAPEID );
